const e={display_name:"إضافة ضجيج",inputs:{latent_image:{name:"الصورة الكامنة"},model:{name:"النموذج"},noise:{name:"الضجيج"},sigmas:{name:"سيغما"}}},n={display_name:"جدولة محاذاة خطواتك",inputs:{denoise:{name:"إزالة الضجيج"},model_type:{name:"نوع النموذج"},steps:{name:"الخطوات"}}},a={display_name:"الموجه الأساسي",inputs:{conditioning:{name:"التهيئة"},model:{name:"النموذج"}}},t={display_name:"الجدولة الأساسية",inputs:{denoise:{name:"إزالة الضجيج"},model:{name:"النموذج"},scheduler:{name:"الجدولة"},steps:{name:"الخطوات"}}},o={display_name:"جدولة أخذ عينات بيتا",inputs:{alpha:{name:"ألفا"},beta:{name:"بيتا"},model:{name:"النموذج"},steps:{name:"الخطوات"}}},m={display_name:"موجه CFG",inputs:{cfg:{name:"CFG"},model:{name:"النموذج"},negative:{name:"سلبي"},positive:{name:"إيجابي"}}},i={display_name:"CFGZeroStar",inputs:{model:{name:"النموذج"}},outputs:{0:{name:"النموذج المعدل"}}},s={display_name:"ضرب انتباه CLIP",inputs:{clip:{name:"CLIP"},k:{name:"K"},out:{name:"الإخراج"},q:{name:"Q"},v:{name:"V"}}},_={description:`[الوصفات]

stable_diffusion: clip-l
stable_cascade: clip-g
sd3: t5 xxl / clip-g / clip-l
stable_audio: t5 base
mochi: t5 xxl
cosmos: old t5 xxl
lumina2: gemma 2 2B
wan: umt5 xxl
hidream: llama-3.1 (موصى به) أو t5`,display_name:"تحميل CLIP",inputs:{clip_name:{name:"اسم CLIP"},device:{name:"الجهاز"},type:{name:"النوع"}}},l={display_name:"دمج CLIP - إضافة",inputs:{clip1:{name:"CLIP 1"},clip2:{name:"CLIP 2"}}},p={display_name:"دمج CLIP - بسيط",inputs:{clip1:{name:"CLIP 1"},clip2:{name:"CLIP 2"},ratio:{name:"النسبة"}}},c={display_name:"دمج CLIP - طرح",inputs:{clip1:{name:"CLIP 1"},clip2:{name:"CLIP 2"},multiplier:{name:"المضاعف"}}},d={display_name:"حفظ CLIP",inputs:{clip:{name:"CLIP"},filename_prefix:{name:"بادئة اسم الملف"}}},r={display_name:"تعيين الطبقة الأخيرة لـ CLIP",inputs:{clip:{name:"CLIP"},stop_at_clip_layer:{name:"التوقف عند طبقة CLIP"}}},u={description:"يقوم بترميز أمر نصي باستخدام نموذج CLIP إلى تمثيل مضمَّن يمكن استخدامه لتوجيه نموذج الانتشار نحو إنشاء صور محددة.",display_name:"ترميز نص CLIP (أمر)",inputs:{clip:{name:"CLIP",tooltip:"نموذج CLIP المستخدم لترميز النص."},text:{name:"النص",tooltip:"النص المراد ترميزه."}},outputs:{0:{tooltip:"تهيئة تحتوي على النص المضمن المستخدم لتوجيه نموذج الانتشار."}}},g={display_name:"ترميز نص CLIP لـ Controlnet",inputs:{clip:{name:"CLIP"},conditioning:{name:"التهيئة"},text:{name:"النص"}}},b={display_name:"ترميز نص CLIP لـ Flux",inputs:{clip:{name:"CLIP"},clip_l:{name:"CLIP-L"},guidance:{name:"التوجيه"},t5xxl:{name:"T5-XXL"}}},y={display_name:"ترميز نص CLIP لـ HiDream",inputs:{clip:{name:"CLIP"},clip_g:{name:"CLIP-G"},clip_l:{name:"CLIP-L"},llama:{name:"LLaMA"},t5xxl:{name:"T5-XXL"}}},k={display_name:"ترميز نص CLIP لـ HunyuanDiT",inputs:{bert:{name:"BERT"},clip:{name:"CLIP"},mt5xl:{name:"mT5-XL"}}},h={description:"يقوم بترميز أمر النظام وأمر المستخدم باستخدام نموذج CLIP إلى تمثيل مضمَّن يمكن استخدامه لتوجيه نموذج الانتشار نحو إنشاء صور محددة.",display_name:"ترميز نص CLIP لـ Lumina2",inputs:{clip:{name:"CLIP",tooltip:"نموذج CLIP المستخدم لترميز النص."},system_prompt:{name:"أمر النظام",tooltip:"يوفر Lumina2 نوعين من أوامر النظام: متفوق: أنت مساعد مصمم لإنشاء صور متفوقة بدرجة عالية من التوافق بين النص والصورة استنادًا إلى الأوامر النصية أو أوامر المستخدم. محاذاة: أنت مساعد مصمم لإنشاء صور عالية الجودة مع أعلى درجة من التوافق بين النص والصورة استنادًا إلى الأوامر النصية."},user_prompt:{name:"أمر المستخدم",tooltip:"النص المراد ترميزه."}},outputs:{0:{tooltip:"تهيئة تحتوي على النص المضمن المستخدم لتوجيه نموذج الانتشار."}}},L={description:"يقوم بترميز النص ويضبط تهيئة الدقة لـ PixArt Alpha. لا ينطبق على PixArt Sigma.",display_name:"ترميز نص CLIP لـ PixArt Alpha",inputs:{clip:{name:"CLIP"},height:{name:"الارتفاع"},text:{name:"النص"},width:{name:"العرض"}}},C={display_name:"ترميز نص CLIP لـ SD3",inputs:{clip:{name:"CLIP"},clip_g:{name:"CLIP-G"},clip_l:{name:"CLIP-L"},empty_padding:{name:"حشو فارغ"},t5xxl:{name:"T5-XXL"}}},S={display_name:"ترميز نص CLIP لـ SDXL",inputs:{clip:{name:"CLIP"},crop_h:{name:"قص الارتفاع"},crop_w:{name:"قص العرض"},height:{name:"الارتفاع"},target_height:{name:"الارتفاع المستهدف"},target_width:{name:"العرض المستهدف"},text_g:{name:"النص G"},text_l:{name:"النص L"},width:{name:"العرض"}}},f={display_name:"مُحسّن ترميز نص CLIP لـ SDXL",inputs:{ascore:{name:"الدرجة A"},clip:{name:"CLIP"},height:{name:"الارتفاع"},text:{name:"النص"},width:{name:"العرض"}}},v={display_name:"ترميز رؤية CLIP",inputs:{clip_vision:{name:"رؤية CLIP"},crop:{name:"القص"},image:{name:"الصورة"}}},I={display_name:"تحميل رؤية CLIP",inputs:{clip_name:{name:"اسم CLIP"}}},P={display_name:"كاني",inputs:{high_threshold:{name:"الحد الأعلى"},image:{name:"الصورة"},low_threshold:{name:"الحد الأدنى"}}},M={display_name:"تحميل نقطة التحقق مع الإعدادات (متوقف)",inputs:{ckpt_name:{name:"اسم نقطة التحقق"},config_name:{name:"اسم الإعداد"}}},A={description:"يقوم بتحميل نقطة تحقق نموذج الانتشار، حيث تُستخدم نماذج الانتشار لإزالة الضجيج من البيانات الكامنة.",display_name:"تحميل نقطة التحقق",inputs:{ckpt_name:{name:"اسم نقطة التحقق",tooltip:"اسم نقطة التحقق (النموذج) المراد تحميله."}},outputs:{0:{tooltip:"النموذج المستخدم لإزالة الضجيج من البيانات الكامنة."},1:{tooltip:"نموذج CLIP المستخدم لترميز أوامر النص."},2:{tooltip:"نموذج VAE المستخدم لترميز وفك ترميز الصور من وإلى الفضاء الكامن."}}},V={display_name:"حفظ نقطة التحقق",inputs:{clip:{name:"CLIP"},filename_prefix:{name:"بادئة اسم الملف"},model:{name:"النموذج"},vae:{name:"VAE"}}},x={display_name:"دمج الخطافات [2]",inputs:{hooks_A:{name:"الخُطاف A"},hooks_B:{name:"الخُطاف B"}}},T={display_name:"دمج الخطافات [4]",inputs:{hooks_A:{name:"الخُطاف A"},hooks_B:{name:"الخُطاف B"},hooks_C:{name:"الخُطاف C"},hooks_D:{name:"الخُطاف D"}}},E={display_name:"دمج الخطافات [8]",inputs:{hooks_A:{name:"الخُطاف A"},hooks_B:{name:"الخُطاف B"},hooks_C:{name:"الخُطاف C"},hooks_D:{name:"الخُطاف D"},hooks_E:{name:"الخُطاف E"},hooks_F:{name:"الخُطاف F"},hooks_G:{name:"الخُطاف G"},hooks_H:{name:"الخُطاف H"}}},D={display_name:"متوسط التهيئة",inputs:{conditioning_from:{name:"تهيئة من"},conditioning_to:{name:"تهيئة إلى"},conditioning_to_strength:{name:"قوة التهيئة إلى"}}},N={display_name:"التهيئة (دمج)",inputs:{conditioning_1:{name:"تهيئة 1"},conditioning_2:{name:"تهيئة 2"}}},G={display_name:"التهيئة (ربط)",inputs:{conditioning_from:{name:"تهيئة من"},conditioning_to:{name:"تهيئة إلى"}}},F={display_name:"التهيئة (تعيين منطقة)",inputs:{conditioning:{name:"التهيئة"},height:{name:"الارتفاع"},strength:{name:"القوة"},width:{name:"العرض"},x:{name:"س"},y:{name:"ص"}}},R={display_name:"التهيئة (تعيين منطقة بالنسبة المئوية)",inputs:{conditioning:{name:"التهيئة"},height:{name:"الارتفاع"},strength:{name:"القوة"},width:{name:"العرض"},x:{name:"س"},y:{name:"ص"}}},B={display_name:"تهيئة نسبة المساحة للفيديو",inputs:{conditioning:{name:"التهيئة"},height:{name:"الارتفاع"},strength:{name:"القوة"},temporal:{name:"زمني"},width:{name:"العرض"},x:{name:"س"},y:{name:"ص"},z:{name:"ع"}}},w={display_name:"تعيين قوة التهيئة",inputs:{conditioning:{name:"التهيئة"},strength:{name:"القوة"}}},U={display_name:"تهيئة دمج افتراضية",inputs:{cond:{name:"تهيئة"},cond_DEFAULT:{name:"تهيئة افتراضية"},hooks:{name:"الخطافات"}}},j={display_name:"التهيئة (تعيين قناع)",inputs:{conditioning:{name:"التهيئة"},mask:{name:"القناع"},set_cond_area:{name:"تعيين منطقة التهيئة"},strength:{name:"القوة"}}},H={display_name:"تعيين خصائص التهيئة",inputs:{cond_NEW:{name:"تهيئة جديدة"},hooks:{name:"الخطافات"},mask:{name:"القناع"},set_cond_area:{name:"تعيين منطقة التهيئة"},strength:{name:"القوة"},timesteps:{name:"خطوات زمنية"}}},X={display_name:"تعيين خصائص التهيئة ودمج",inputs:{cond:{name:"تهيئة"},cond_NEW:{name:"تهيئة جديدة"},hooks:{name:"الخطافات"},mask:{name:"القناع"},set_cond_area:{name:"تعيين منطقة التهيئة"},strength:{name:"القوة"},timesteps:{name:"خطوات زمنية"}}},z={display_name:"تعيين نطاق الخطوات الزمنية للتهيئة",inputs:{conditioning:{name:"التهيئة"},end:{name:"النهاية"},start:{name:"البداية"}}},K={display_name:"تهيئة الصوت المستقر",inputs:{negative:{name:"سلبي"},positive:{name:"إيجابي"},seconds_start:{name:"ثواني البداية"},seconds_total:{name:"إجمالي الثواني"}},outputs:{0:{name:"إيجابي"},1:{name:"سلبي"}}},O={display_name:"نطاق الخطوات الزمنية",inputs:{end_percent:{name:"نسبة النهاية"},start_percent:{name:"نسبة البداية"}},outputs:{1:{name:"قبل النطاق"},2:{name:"بعد النطاق"}}},W={display_name:"تصفير التهيئة",inputs:{conditioning:{name:"تهيئة"}}},Y={display_name:"تطبيق ControlNet (قديم)",inputs:{conditioning:{name:"تهيئة"},control_net:{name:"شبكة التحكم"},image:{name:"صورة"},strength:{name:"القوة"}}},q={display_name:"تطبيق ControlNet",inputs:{control_net:{name:"شبكة التحكم"},end_percent:{name:"نسبة النهاية"},image:{name:"صورة"},negative:{name:"سلبي"},positive:{name:"إيجابي"},start_percent:{name:"نسبة البداية"},strength:{name:"القوة"},vae:{name:"VAE"}},outputs:{0:{name:"إيجابي"},1:{name:"سلبي"}}},Z={display_name:"تطبيق ControlNet مع VAE",inputs:{control_net:{name:"شبكة التحكم"},end_percent:{name:"نسبة النهاية"},image:{name:"صورة"},negative:{name:"سلبي"},positive:{name:"إيجابي"},start_percent:{name:"نسبة البداية"},strength:{name:"القوة"},vae:{name:"VAE"}},outputs:{0:{name:"إيجابي"},1:{name:"سلبي"}}},Q={display_name:"تطبيق ControlNet للترميم - علي ماما",inputs:{control_net:{name:"شبكة التحكم"},end_percent:{name:"نسبة النهاية"},image:{name:"صورة"},mask:{name:"قناع"},negative:{name:"سلبي"},positive:{name:"إيجابي"},start_percent:{name:"نسبة البداية"},strength:{name:"القوة"},vae:{name:"VAE"}},outputs:{0:{name:"إيجابي"},1:{name:"سلبي"}}},J={display_name:"تحميل نموذج ControlNet",inputs:{control_net_name:{name:"اسم شبكة التحكم"}}},$={display_name:"تحويل صورة كوزموس إلى فيديو كامِن",inputs:{batch_size:{name:"حجم الدفعة"},end_image:{name:"الصورة النهاية"},height:{name:"الارتفاع"},length:{name:"المدة"},start_image:{name:"الصورة البداية"},vae:{name:"VAE"},width:{name:"العرض"}}},ee={display_name:"إنشاء إطار مفتاحي للخطاف",inputs:{prev_hook_kf:{name:"الإطار المفتاحي السابق"},start_percent:{name:"نسبة البداية"},strength_mult:{name:"معامل القوة"}},outputs:{0:{name:"إطار مفتاحي للخطاف"}}},ne={display_name:"إنشاء إطارات مفتاحية من القيم العشرية",inputs:{end_percent:{name:"نسبة النهاية"},floats_strength:{name:"قوة القيم العشرية"},prev_hook_kf:{name:"الإطار المفتاحي السابق"},print_keyframes:{name:"طباعة الإطارات المفتاحية"},start_percent:{name:"نسبة البداية"}},outputs:{0:{name:"إطار مفتاحي للخطاف"}}},ae={display_name:"إنشاء إطارات مفتاحية بخطاف (مُInterpolated)",inputs:{end_percent:{name:"نسبة النهاية"},interpolation:{name:"الاستيفاء"},keyframes_count:{name:"عدد الإطارات المفتاحية"},prev_hook_kf:{name:"الإطار المفتاحي السابق"},print_keyframes:{name:"طباعة الإطارات المفتاحية"},start_percent:{name:"نسبة البداية"},strength_end:{name:"قوة النهاية"},strength_start:{name:"قوة البداية"}},outputs:{0:{name:"إطار مفتاحي للخطاف"}}},te={display_name:"إنشاء خطاف LoRA",inputs:{lora_name:{name:"اسم LoRA"},prev_hooks:{name:"الخطافات السابقة"},strength_clip:{name:"قوة القص"},strength_model:{name:"قوة النموذج"}}},oe={display_name:"إنشاء خطاف LoRA (النموذج فقط)",inputs:{lora_name:{name:"اسم LoRA"},prev_hooks:{name:"الخطافات السابقة"},strength_model:{name:"قوة النموذج"}}},me={display_name:"إنشاء خطاف كنموذج LoRA",inputs:{ckpt_name:{name:"اسم نقطة الحفظ"},prev_hooks:{name:"الخطافات السابقة"},strength_clip:{name:"قوة القص"},strength_model:{name:"قوة النموذج"}}},ie={display_name:"إنشاء خطاف كنموذج LoRA (النموذج فقط)",inputs:{ckpt_name:{name:"اسم نقطة الحفظ"},prev_hooks:{name:"الخطافات السابقة"},strength_model:{name:"قوة النموذج"}}},se={description:"إنشاء فيديو من الصور.",display_name:"إنشاء فيديو",inputs:{audio:{name:"الصوت",tooltip:"الصوت الذي سيتم إضافته للفيديو."},fps:{name:"الإطارات في الثانية"},images:{name:"الصور",tooltip:"الصور التي سيتم إنشاء الفيديو منها."}}},_e={display_name:"قص القناع",inputs:{height:{name:"الارتفاع"},mask:{name:"قناع"},width:{name:"العرض"},x:{name:"س"},y:{name:"ص"}}},le={display_name:"تحميل نموذج ControlNet (فرق)",inputs:{control_net_name:{name:"اسم شبكة التحكم"},model:{name:"النموذج"}}},pe={display_name:"انتشار تفاضلي",inputs:{model:{name:"النموذج"}}},ce={display_name:"تحميل Diffusers",inputs:{model_path:{name:"مسار النموذج"}}},de={display_name:"تعطيل الضجيج"},re={display_name:"موجّه CFG مزدوج",inputs:{cfg_cond2_negative:{name:"شرط CFG 2 سلبي"},cfg_conds:{name:"شروط CFG"},cond1:{name:"الشرط 1"},cond2:{name:"الشرط 2"},model:{name:"النموذج"},negative:{name:"سلبي"}}},ue={description:`[الوصفات]

sdxl: clip-l, clip-g
sd3: clip-l, clip-g / clip-l, t5 / clip-g, t5
flux: clip-l, t5
hidream: على الأقل واحد من t5 أو llama، يفضل t5 و llama`,display_name:"محمل DualCLIP",inputs:{clip_name1:{name:"اسم_clip1"},clip_name2:{name:"اسم_clip2"},device:{name:"الجهاز"},type:{name:"النوع"}}},ge={display_name:"فيديو كوزموس كامن فارغ",inputs:{batch_size:{name:"حجم_الدُفعة"},height:{name:"الارتفاع"},length:{name:"المدة"},width:{name:"العرض"}}},be={display_name:"فيديو هونييوان كامن فارغ",inputs:{batch_size:{name:"حجم_الدُفعة"},height:{name:"الارتفاع"},length:{name:"المدة"},width:{name:"العرض"}}},ye={display_name:"صورة فارغة",inputs:{batch_size:{name:"حجم_الدُفعة"},color:{name:"اللون"},height:{name:"الارتفاع"},width:{name:"العرض"}}},ke={display_name:"فيديو LTXV كامن فارغ",inputs:{batch_size:{name:"حجم_الدُفعة"},height:{name:"الارتفاع"},length:{name:"المدة"},width:{name:"العرض"}}},he={display_name:"صوت كامن فارغ",inputs:{batch_size:{name:"حجم_الدُفعة",tooltip:"عدد الصور الكامنة في الدُفعة."},seconds:{name:"الثواني"}}},Le={display_name:"هونييوان 3D كامن فارغ نسخة 2",inputs:{batch_size:{name:"حجم_الدُفعة",tooltip:"عدد الصور الكامنة في الدُفعة."},resolution:{name:"الدقة"}}},Ce={description:"إنشاء دفعة جديدة من الصور الكامنة الفارغة ليتم تنظيفها عبر التوليد.",display_name:"صورة كامنة فارغة",inputs:{batch_size:{name:"حجم_الدُفعة",tooltip:"عدد الصور الكامنة في الدُفعة."},height:{name:"الارتفاع",tooltip:"ارتفاع الصور الكامنة بالبكسل."},width:{name:"العرض",tooltip:"عرض الصور الكامنة بالبكسل."}},outputs:{0:{tooltip:"دفعة الصور الكامنة الفارغة."}}},Se={display_name:"فيديو موتشي كامن فارغ",inputs:{batch_size:{name:"حجم_الدُفعة"},height:{name:"الارتفاع"},length:{name:"المدة"},width:{name:"العرض"}}},fe={display_name:"صورة SD3 كامنة فارغة",inputs:{batch_size:{name:"حجم_الدُفعة"},height:{name:"الارتفاع"},width:{name:"العرض"}}},ve={display_name:"مجدول أُسّي",inputs:{sigma_max:{name:"سيغما_القصوى"},sigma_min:{name:"سيغما_الدنيا"},steps:{name:"الخطوات"}}},Ie={display_name:"تمديد قيم سيغما المتوسطة",inputs:{end_at_sigma:{name:"النهاية_عند_السيغما"},sigmas:{name:"قيم_السيغما"},spacing:{name:"المسافة"},start_at_sigma:{name:"البداية_عند_السيغما"},steps:{name:"الخطوات"}}},Pe={display_name:"قناع التمويه",inputs:{bottom:{name:"الأسفل"},left:{name:"اليسار"},mask:{name:"القناع"},right:{name:"اليمين"},top:{name:"الأعلى"}}},Me={display_name:"عكس قيم السيغما",inputs:{sigmas:{name:"قيم_السيغما"}}},Ae={description:"تعطيل كامل لتضمين الإرشاد على موديلات فلوكس ومشابهة.",display_name:"تعطيل إرشاد فلوكس",inputs:{conditioning:{name:"التهيئة"}}},Ve={display_name:"إرشاد فلوكس",inputs:{conditioning:{name:"التهيئة"},guidance:{name:"الإرشاد"}}},xe={description:"توسيع الصورة بناءً على الوصف.",display_name:"Flux.1 توسيع الصورة",inputs:{bottom:{name:"الأسفل",tooltip:"عدد البكسلات لتوسيع الصورة من الأسفل"},control_after_generate:{name:"التحكم بعد التوليد"},guidance:{name:"الإرشاد",tooltip:"قوة الإرشاد لعملية توليد الصورة"},image:{name:"الصورة"},left:{name:"اليسار",tooltip:"عدد البكسلات لتوسيع الصورة من اليسار"},prompt:{name:"الوصف",tooltip:"الوصف المطلوب لتوليد الصورة"},prompt_upsampling:{name:"تحسين_الوصف",tooltip:"ما إذا كان يجب تحسين الوصف. إذا تم تفعيله، يتم تعديل الوصف تلقائيًا للحصول على توليد إبداعي أكثر، لكن النتائج غير حتمية (نفس البذرة لن تنتج نفس النتيجة بالضبط)."},right:{name:"اليمين",tooltip:"عدد البكسلات لتوسيع الصورة من اليمين"},seed:{name:"البذرة",tooltip:"البذرة العشوائية المستخدمة لإنشاء الضجيج."},steps:{name:"الخطوات",tooltip:"عدد الخطوات في عملية توليد الصورة"},top:{name:"الأعلى",tooltip:"عدد البكسلات لتوسيع الصورة من الأعلى"}}},Te={description:"ملء الصورة بناءً على القناع والوصف.",display_name:"Flux.1 ملء الصورة",inputs:{control_after_generate:{name:"التحكم بعد التوليد"},guidance:{name:"الإرشاد",tooltip:"قوة الإرشاد لعملية توليد الصورة"},image:{name:"الصورة"},mask:{name:"القناع"},prompt:{name:"الوصف",tooltip:"الوصف المطلوب لتوليد الصورة"},prompt_upsampling:{name:"تحسين_الوصف",tooltip:"ما إذا كان يجب تحسين الوصف. إذا تم تفعيله، يتم تعديل الوصف تلقائيًا للحصول على توليد إبداعي أكثر، لكن النتائج غير حتمية (نفس البذرة لن تنتج نفس النتيجة بالضبط)."},seed:{name:"البذرة",tooltip:"البذرة العشوائية المستخدمة لإنشاء الضجيج."},steps:{name:"الخطوات",tooltip:"عدد الخطوات في عملية توليد الصورة"}}},Ee={description:"ينشئ صورًا باستخدام Flux Pro 1.1 Ultra عبر API بناءً على الوصف والدقة.",display_name:"Flux 1.1 [pro] صورة فائقة",inputs:{aspect_ratio:{name:"نسبة_الأبعاد",tooltip:"نسبة أبعاد الصورة؛ يجب أن تكون بين 1:4 و4:1."},control_after_generate:{name:"التحكم بعد التوليد"},image_prompt:{name:"وصف_صورة"},image_prompt_strength:{name:"قوة_وصف_الصورة",tooltip:"نسبة الدمج بين الوصف النصي ووصف الصورة."},prompt:{name:"الوصف",tooltip:"الوصف لتوليد الصورة"},prompt_upsampling:{name:"تحسين_الوصف",tooltip:"هل يجب إجراء تحسين على الوصف؟ إذا كان مفعلاً، يتم تعديل الوصف تلقائيًا للحصول على توليد أكثر إبداعًا، لكن النتائج غير حتمية (نفس البذرة لن تعطي نفس النتيجة تمامًا)."},raw:{name:"خام",tooltip:"عند التفعيل، يتم توليد صور أقل معالجة وأكثر طبيعية المظهر."},seed:{name:"البذرة",tooltip:"البذرة العشوائية المستخدمة لإنشاء الضجيج."}}},De={description:"يطبق تحجيمًا معتمدًا على الترددات على الإرشاد",display_name:"FreSca",inputs:{freq_cutoff:{name:"قطع_التردد",tooltip:"عدد مؤشرات التردد حول المركز التي تعتبر ترددات منخفضة"},model:{name:"النموذج"},scale_high:{name:"تحجيم_التردد_العالي",tooltip:"عامل التحجيم لمكونات التردد العالي"},scale_low:{name:"تحجيم_التردد_المنخفض",tooltip:"عامل التحجيم لمكونات التردد المنخفض"}}},Ne={display_name:"FreeU",inputs:{b1:{name:"b1"},b2:{name:"b2"},model:{name:"النموذج"},s1:{name:"s1"},s2:{name:"s2"}}},Ge={display_name:"FreeU_V2",inputs:{b1:{name:"b1"},b2:{name:"b2"},model:{name:"النموذج"},s1:{name:"s1"},s2:{name:"s2"}}},Fe={display_name:"GITSScheduler",inputs:{coeff:{name:"المعامل"},denoise:{name:"إزالة_الضجيج"},steps:{name:"الخطوات"}}},Re={display_name:"GLIGENLoader",inputs:{gligen_name:{name:"اسم_gligen"}}},Be={display_name:"تطبيق صندوق نص GLIGEN",inputs:{clip:{name:"clip"},conditioning_to:{name:"التكييف_إلى"},gligen_textbox_model:{name:"نموذج_صندوق_النص_GLIGEN"},height:{name:"الارتفاع"},text:{name:"النص"},width:{name:"العرض"},x:{name:"س_محور"},y:{name:"ص_محور"}}},we={description:"يستخرج جميع المكونات من الفيديو: الإطارات، الصوت، ومعدل الإطارات.",display_name:"استخراج مكونات الفيديو",inputs:{video:{name:"الفيديو",tooltip:"الفيديو الذي سيتم استخراج المكونات منه."}},outputs:{0:{name:"الصور"},1:{name:"الصوت"},2:{name:"معدل_الإطارات"}}},Ue={display_name:"توسيع القناع",inputs:{expand:{name:"التوسيع"},mask:{name:"القناع"},tapered_corners:{name:"زوايا_منحدرة"}}},je={display_name:"Hunyuan3Dv2التكييف",inputs:{clip_vision_output:{name:"مخرج_clip_الرؤية"}},outputs:{0:{name:"إيجابي"},1:{name:"سلبي"}}},He={display_name:"Hunyuan3Dv2التكييف متعدد الرؤى",inputs:{back:{name:"الخلفي"},front:{name:"الأمامي"},left:{name:"الأيسر"},right:{name:"الأيمن"}},outputs:{0:{name:"إيجابي"},1:{name:"سلبي"}}},Xe={display_name:"Hunyuan صورة إلى فيديو",inputs:{batch_size:{name:"حجم_الدفعة"},guidance_type:{name:"نوع_الإرشاد"},height:{name:"الارتفاع"},length:{name:"الطول"},positive:{name:"إيجابي"},start_image:{name:"صورة_البداية"},vae:{name:"vae"},width:{name:"العرض"}},outputs:{0:{name:"إيجابي"},1:{name:"كامِن"}}},ze={display_name:"HyperTile",inputs:{max_depth:{name:"أقصى_عمق"},model:{name:"النموذج"},scale_depth:{name:"تحجيم_العمق"},swap_size:{name:"حجم_التبديل"},tile_size:{name:"حجم_القرميدة"}}},Ke={display_name:"محمل الشبكات الفائقة",inputs:{hypernetwork_name:{name:"اسم_الشبكة_الفائقة"},model:{name:"النموذج"},strength:{name:"القوة"}}},Oe={description:`ينشئ صورًا تزامنيًا باستخدام نموذج Ideogram V1.

روابط الصور متاحة لفترة محدودة؛ إذا أردت الاحتفاظ بالصورة، يجب تنزيلها.`,display_name:"Ideogram V1",inputs:{aspect_ratio:{name:"نسبة_الأبعاد",tooltip:"نسبة الأبعاد لتوليد الصورة."},control_after_generate:{name:"التحكم بعد التوليد"},magic_prompt_option:{name:"خيار_الوصف_السحري",tooltip:"تحديد ما إذا كان يجب استخدام MagicPrompt في التوليد"},negative_prompt:{name:"الوصف_السلبي",tooltip:"وصف ما يجب استبعاده من الصورة"},num_images:{name:"عدد_الصور"},prompt:{name:"الوصف",tooltip:"الوصف لتوليد الصورة"},seed:{name:"البذرة"},turbo:{name:"الوضع_السريع",tooltip:"هل تستخدم وضع التيربو (توليد أسرع، جودة أقل محتملة)"}}},We={description:`ينشئ الصور بشكل متزامن باستخدام نموذج إيديوغرام الإصدار 2.

روابط الصور متاحة لفترة محدودة من الوقت؛ إذا كنت ترغب في الاحتفاظ بالصورة، يجب عليك تنزيلها.`,display_name:"إيديوغرام الإصدار 2",inputs:{aspect_ratio:{name:"نسبة العرض إلى الارتفاع",tooltip:"نسبة العرض إلى الارتفاع لتوليد الصورة. يتم تجاهلها إذا لم يتم تعيين الدقة إلى تلقائي."},control_after_generate:{name:"التحكم بعد التوليد"},magic_prompt_option:{name:"خيار الموجه السحري",tooltip:"تحديد ما إذا كان يجب استخدام الموجه السحري في التوليد"},negative_prompt:{name:"الموجه السلبي",tooltip:"وصف ما يجب استبعاده من الصورة"},num_images:{name:"عدد الصور"},prompt:{name:"الموجه",tooltip:"الموجه لتوليد الصورة"},resolution:{name:"الدقة",tooltip:"دقة توليد الصورة. إذا لم يتم تعيينها إلى تلقائي، فإنها تتجاوز إعداد نسبة العرض إلى الارتفاع."},seed:{name:"البذرة"},style_type:{name:"نوع الأسلوب",tooltip:"نوع الأسلوب للتوليد (الإصدار 2 فقط)"},turbo:{name:"تيربو",tooltip:"هل يتم استخدام وضع التيربو (توليد أسرع، وجودة قد تكون أقل)"}}},Ye={description:`ينشئ الصور بشكل متزامن باستخدام نموذج إيديوغرام الإصدار 3.

يدعم التوليد العادي للصور من النصوص وتحرير الصور مع القناع.
روابط الصور متاحة لفترة محدودة من الوقت؛ إذا كنت ترغب في الاحتفاظ بالصورة، يجب عليك تنزيلها.`,display_name:"إيديوغرام الإصدار 3",inputs:{aspect_ratio:{name:"نسبة العرض إلى الارتفاع",tooltip:"نسبة العرض إلى الارتفاع لتوليد الصورة. يتم تجاهلها إذا لم يتم تعيين الدقة إلى تلقائي."},control_after_generate:{name:"التحكم بعد التوليد"},image:{name:"الصورة",tooltip:"صورة مرجعية اختيارية لتحرير الصورة."},magic_prompt_option:{name:"خيار الموجه السحري",tooltip:"تحديد ما إذا كان يجب استخدام الموجه السحري في التوليد"},mask:{name:"القناع",tooltip:"قناع اختياري للرسم داخل المناطق (سيتم استبدال المناطق البيضاء)"},num_images:{name:"عدد الصور"},prompt:{name:"الموجه",tooltip:"الموجه لتوليد الصورة أو تحريرها"},rendering_speed:{name:"سرعة العرض",tooltip:"التحكم في التوازن بين سرعة التوليد والجودة"},resolution:{name:"الدقة",tooltip:"دقة توليد الصورة. إذا لم يتم تعيينها إلى تلقائي، فإنها تتجاوز إعداد نسبة العرض إلى الارتفاع."},seed:{name:"البذرة"}}},qe={display_name:"دفعة الصور",inputs:{image1:{name:"الصورة 1"},image2:{name:"الصورة 2"}}},Ze={display_name:"مزج الصور",inputs:{blend_factor:{name:"عامل المزج"},blend_mode:{name:"طريقة المزج"},image1:{name:"الصورة 1"},image2:{name:"الصورة 2"}}},Qe={display_name:"تمويه الصورة",inputs:{blur_radius:{name:"نصف قطر التمويه"},image:{name:"الصورة"},sigma:{name:"سيغما"}}},Je={display_name:"لون الصورة إلى قناع",inputs:{color:{name:"اللون"},image:{name:"الصورة"}}},$e={display_name:"تركيب صورة مع قناع",inputs:{destination:{name:"الوجهة"},mask:{name:"القناع"},resize_source:{name:"تغيير حجم المصدر"},source:{name:"المصدر"},x:{name:"إحداثي X"},y:{name:"إحداثي Y"}}},en={display_name:"اقتصاص الصورة",inputs:{height:{name:"الارتفاع"},image:{name:"الصورة"},width:{name:"العرض"},x:{name:"إحداثي X"},y:{name:"إحداثي Y"}}},nn={display_name:"صورة من دفعة",inputs:{batch_index:{name:"فهرس الدفعة"},image:{name:"الصورة"},length:{name:"الطول"}}},an={display_name:"عكس الصورة",inputs:{image:{name:"الصورة"}}},tn={display_name:"محمل نقطة تحقق الصور فقط (نموذج img2vid)",inputs:{ckpt_name:{name:"اسم نقطة التحقق"}}},on={display_name:"حفظ نقطة تحقق الصور فقط",inputs:{clip_vision:{name:"رؤية Clip"},filename_prefix:{name:"بادئة اسم الملف"},model:{name:"النموذج"},vae:{name:"VAE"}}},mn={display_name:"توسيع الصورة للرسم الخارجي",inputs:{bottom:{name:"الأسفل"},feathering:{name:"التدرج"},image:{name:"الصورة"},left:{name:"اليسار"},right:{name:"اليمين"},top:{name:"الأعلى"}}},sn={display_name:"تكميم الصورة",inputs:{colors:{name:"الألوان"},dither:{name:"التنقيط"},image:{name:"الصورة"}}},_n={display_name:"تحويل الصورة من RGB إلى YUV",inputs:{image:{name:"الصورة"}},outputs:{0:{name:"Y"},1:{name:"U"},2:{name:"V"}}},ln={display_name:"تكبير الصورة",inputs:{crop:{name:"اقتصاص"},height:{name:"الارتفاع"},image:{name:"الصورة"},upscale_method:{name:"طريقة التكبير"},width:{name:"العرض"}}},pn={display_name:"تكبير الصورة بمقدار",inputs:{image:{name:"الصورة"},scale_by:{name:"التكبير بمقدار"},upscale_method:{name:"طريقة التكبير"}}},cn={display_name:"تكبير الصورة إلى عدد بكسلات معين",inputs:{image:{name:"الصورة"},megapixels:{name:"الميغابكسل"},upscale_method:{name:"طريقة التكبير"}}},dn={display_name:"تحسين وضوح الصورة",inputs:{alpha:{name:"ألفا"},image:{name:"الصورة"},sharpen_radius:{name:"نصف قطر التحسين"},sigma:{name:"سيغما"}}},rn={display_name:"تحويل الصورة إلى قناع",inputs:{channel:{name:"القناة"},image:{name:"الصورة"}}},un={display_name:"تكبير الصورة (باستخدام نموذج)",inputs:{image:{name:"الصورة"},upscale_model:{name:"نموذج التكبير"}}},gn={display_name:"تحويل الصورة من YUV إلى RGB",inputs:{U:{name:"U"},V:{name:"V"},Y:{name:"Y"}}},bn={display_name:"تكوين نموذج التلوين",inputs:{mask:{name:"قناع"},negative:{name:"سلبي"},noise_mask:{name:"قناع الضجيج",tooltip:"أضف قناع ضجيج إلى المتغير الكامن بحيث يحدث التوليد داخل القناع فقط. قد يحسن النتائج أو يفسدها تمامًا اعتمادًا على النموذج."},pixels:{name:"بكسلات"},positive:{name:"إيجابي"},vae:{name:"vae"}},outputs:{0:{name:"إيجابي"},1:{name:"سلبي"},2:{name:"المتغير الكامن"}}},yn={display_name:"تكوين توجيهي للبيكسل إلى بيكسل",inputs:{negative:{name:"سلبي"},pixels:{name:"بكسلات"},positive:{name:"إيجابي"},vae:{name:"vae"}},outputs:{0:{name:"إيجابي"},1:{name:"سلبي"},2:{name:"المتغير الكامن"}}},kn={display_name:"عكس القناع",inputs:{mask:{name:"قناع"}}},hn={display_name:"دمج الصورة مع ألفا",inputs:{alpha:{name:"ألفا"},image:{name:"صورة"}}},Ln={description:"يستخدم النموذج المقدم، والتوجيه الإيجابي والسلبي لإزالة الضجيج من الصورة الكامنة.",display_name:"KSampler",inputs:{cfg:{name:"cfg",tooltip:"مقياس التوجيه بدون مصنف يوازن بين الإبداع والالتزام بالتوجيه. القيم الأعلى تؤدي إلى صور أقرب للنص، لكن القيم العالية جدًا تؤثر سلبًا على الجودة."},control_after_generate:{name:"التحكم بعد الإنشاء"},denoise:{name:"ازاله الضجيج",tooltip:"مقدار إزالة الضجيج المطبق، القيم الأقل تحافظ على هيكل الصورة الأصلية مما يسمح بأخذ العينات من صورة إلى أخرى."},latent_image:{name:"الصوره الكامنه",tooltip:"الصورة الكامنة التي سيتم إزالة الضجيج منها."},model:{name:"النمودج",tooltip:"النموذج المستخدم لإزالة الضجيج من الصورة الكامنة المدخلة."},negative:{name:"سلبي",tooltip:"التوجيه الذي يصف الخصائص التي تريد استبعادها من الصورة."},positive:{name:"إيجابي",tooltip:"التوجيه الذي يصف الخصائص التي تريد تضمينها في الصورة."},sampler_name:{name:"اسم المقطع",tooltip:"الخوارزمية المستخدمة أثناء أخذ العينات، قد تؤثر على الجودة، السرعة، وأسلوب الناتج."},scheduler:{name:"المجدول",tooltip:"الجدول الزمني يتحكم في كيفية إزالة الضجيج تدريجيًا لتشكيل الصورة."},seed:{name:"بذرة",tooltip:"البذرة العشوائية المستخدمة لإنشاء الضجيج."},steps:{name:"الخطوات",tooltip:"عدد الخطوات المستخدمة في عملية إزالة الضجيج."}},outputs:{0:{tooltip:"الصورة الكامنة بعد إزالة الضجيج."}}},Cn={display_name:"KSampler (متقدم)",inputs:{add_noise:{name:"اضافة ضجيج"},cfg:{name:"cfg"},control_after_generate:{name:"التحكم بعد الإنشاء"},end_at_step:{name:"توقف عند الخطوة"},latent_image:{name:"الصوره الكامنة"},model:{name:"النموذج"},negative:{name:"سلبي"},noise_seed:{name:"بذرة الضجيج"},positive:{name:"إيجابي"},return_with_leftover_noise:{name:"أخرج بالضجيج المتبقي"},sampler_name:{name:"اسم المقطع"},scheduler:{name:"المجدول"},start_at_step:{name:"ابدأ بالخطوة"},steps:{name:"الخطوات"}}},Sn={display_name:"KSamplerSelect",inputs:{sampler_name:{name:"sampler_name"}}},fn={display_name:"جدول كراس",inputs:{rho:{name:"رو"},sigma_max:{name:"سيجما ماكس"},sigma_min:{name:"سيجما مين"},steps:{name:"خطوات"}}},vn={description:"تحويل الصور الثابتة إلى فيديوهات سينمائية مع حركات كاميرا احترافية تحاكي التصوير السينمائي الحقيقي. تحكم في زووم، دوران، تحريك الكاميرا، الميل، والرؤية من منظور الشخص الأول مع الحفاظ على تركيز الصورة الأصلية.",display_name:"تحكم كاميرا كليغ: صورة إلى فيديو",inputs:{aspect_ratio:{name:"نسبة العرض إلى الارتفاع"},camera_control:{name:"تحكم الكاميرا",tooltip:"يمكن إنشاؤه باستخدام عقدة تحكم كاميرا كليغ. يتحكم في حركة الكاميرا أثناء توليد الفيديو."},cfg_scale:{name:"مقياس CFG"},negative_prompt:{name:"نص التوجيه السلبي",tooltip:"نص التوجيه السلبي"},prompt:{name:"نص التوجيه الإيجابي",tooltip:"نص التوجيه الإيجابي"},start_frame:{name:"الإطار الابتدائي",tooltip:"صورة مرجعية - رابط أو نص مشفر Base64، لا تتجاوز 10 ميغابايت، الدقة لا تقل عن 300×300 بكسل، نسبة العرض إلى الارتفاع بين 1:2.5 و2.5:1. يجب ألا يتضمن Base64 بادئة data:image."}},outputs:{1:{name:"معرّف الفيديو"},2:{name:"المدة"}}},In={description:"تحويل النصوص إلى فيديوهات سينمائية مع حركات كاميرا احترافية تحاكي التصوير السينمائي الحقيقي. تحكم في زووم، دوران، تحريك الكاميرا، الميل، والرؤية من منظور الشخص الأول مع الحفاظ على تركيز النص الأصلي.",display_name:"تحكم كاميرا كليغ: نص إلى فيديو",inputs:{aspect_ratio:{name:"نسبة العرض إلى الارتفاع"},camera_control:{name:"تحكم الكاميرا",tooltip:"يمكن إنشاؤه باستخدام عقدة تحكم كاميرا كليغ. يتحكم في حركة الكاميرا أثناء توليد الفيديو."},cfg_scale:{name:"مقياس CFG"},negative_prompt:{name:"نص التوجيه السلبي",tooltip:"نص التوجيه السلبي"},prompt:{name:"نص التوجيه الإيجابي",tooltip:"نص التوجيه الإيجابي"}},outputs:{1:{name:"معرّف الفيديو"},2:{name:"المدة"}}},Pn={description:"يتيح تحديد خيارات التكوين لتأثيرات تحكم كاميرا كليغ وحركة الكاميرا.",display_name:"تحكم كاميرا كليغ",inputs:{camera_control_type:{name:"نوع تحكم الكاميرا"},horizontal_movement:{name:"الحركة الأفقية",tooltip:"يتحكم في حركة الكاميرا على المحور الأفقي (المحور X). القيم السالبة تعني التحرك لليسار، والقيم الموجبة تعني التحرك لليمين."},pan:{name:"تدوير Pan",tooltip:"يتحكم في دوران الكاميرا في المستوى الرأسي (المحور X). القيم السالبة تعني دوران لأسفل، والقيم الموجبة تعني دوران لأعلى."},roll:{name:"تدوير Roll",tooltip:"يتحكم في دوران الكاميرا حول المحور Z. القيم السالبة تعني دوران عكس عقارب الساعة، والقيم الموجبة تعني دوران مع عقارب الساعة."},tilt:{name:"تدوير Tilt",tooltip:"يتحكم في دوران الكاميرا في المستوى الأفقي (المحور Y). القيم السالبة تعني دوران لليسار، والقيم الموجبة تعني دوران لليمين."},vertical_movement:{name:"الحركة الرأسية",tooltip:"يتحكم في حركة الكاميرا على المحور الرأسي (المحور Y). القيم السالبة تعني التحرك للأسفل، والقيم الموجبة تعني التحرك للأعلى."},zoom:{name:"التكبير",tooltip:"يتحكم في تغيير طول البعد البؤري للكاميرا. القيم السالبة تعني مجال رؤية أضيق، والقيم الموجبة تعني مجال رؤية أوسع."}},outputs:{0:{name:"تحكم الكاميرا"}}},Mn={description:"تحقيق تأثيرات خاصة مختلفة عند توليد فيديو بناءً على مشهد التأثير. ستوضع الصورة الأولى على الجانب الأيسر، والثانية على الجانب الأيمن من التركيب.",display_name:"تأثيرات فيديو شخصية مزدوجة كليغ",inputs:{duration:{name:"المدة"},effect_scene:{name:"مشهد التأثير"},image_left:{name:"الصورة اليسرى",tooltip:"الصورة على الجانب الأيسر"},image_right:{name:"الصورة اليمنى",tooltip:"الصورة على الجانب الأيمن"},mode:{name:"الوضع"},model_name:{name:"اسم النموذج"}},outputs:{1:{name:"المدة"}}},An={description:"عقدة تحويل الصورة إلى فيديو في كليغ",display_name:"كليغ صورة إلى فيديو",inputs:{aspect_ratio:{name:"نسبة العرض إلى الارتفاع"},cfg_scale:{name:"مقياس CFG"},duration:{name:"المدة"},mode:{name:"الوضع"},model_name:{name:"اسم النموذج"},negative_prompt:{name:"نص التوجيه السلبي",tooltip:"نص التوجيه السلبي"},prompt:{name:"نص التوجيه الإيجابي",tooltip:"نص التوجيه الإيجابي"},start_frame:{name:"الإطار الابتدائي",tooltip:"صورة مرجعية - رابط أو نص مشفر Base64، لا تتجاوز 10 ميغابايت، الدقة لا تقل عن 300×300 بكسل، نسبة العرض إلى الارتفاع بين 1:2.5 و2.5:1. يجب ألا يتضمن Base64 بادئة data:image."}},outputs:{1:{name:"معرّف الفيديو"},2:{name:"المدة"}}},Vn={description:"عقدة توليد صورة كليغ. توليد صورة من نص مع صورة مرجعية اختيارية.",display_name:"توليد صورة كليغ",inputs:{aspect_ratio:{name:"نسبة العرض إلى الارتفاع"},human_fidelity:{name:"تشابه الموضوع",tooltip:"تشابه المرجع للموضوع البشري"},image:{name:"صورة"},image_fidelity:{name:"شدة المرجع للصورة المرفوعة",tooltip:"شدة المرجع للصور المرفوعة من المستخدم"},image_type:{name:"نوع الصورة"},model_name:{name:"اسم النموذج"},n:{name:"عدد الصور",tooltip:"عدد الصور المولدة"},negative_prompt:{name:"نص التوجيه السلبي",tooltip:"نص التوجيه السلبي"},prompt:{name:"نص التوجيه الإيجابي",tooltip:"نص التوجيه الإيجابي"}}},xn={description:"عقدة مزامنة شفاه كليغ من الصوت إلى الفيديو. تزامن حركة الفم في فيديو مع محتوى صوتي.",display_name:"مزامنة شفاه كليغ مع الصوت",inputs:{audio:{name:"صوت"},video:{name:"فيديو"},voice_language:{name:"لغة الصوت"}},outputs:{1:{name:"معرّف الفيديو"},2:{name:"المدة"}}},Tn={description:"عقدة مزامنة شفاه كليغ من النص إلى الفيديو. تزامن حركة الفم في فيديو مع نص توجيهي.",display_name:"مزامنة شفاه كليغ مع النص",inputs:{text:{name:"نص",tooltip:"محتوى النص لتوليد فيديو مزامنة الشفاه. مطلوب عند الوضع text2video. الحد الأقصى للطول 120 حرفًا."},video:{name:"فيديو"},voice:{name:"صوت"},voice_speed:{name:"سرعة الصوت",tooltip:"معدل الكلام. النطاق الصحيح: 0.8~2.0، بدقة عشرية واحدة."}},outputs:{1:{name:"معرّف الفيديو"},2:{name:"المدة"}}},En={description:"تحقيق تأثيرات خاصة مختلفة عند توليد فيديو بناءً على مشهد التأثير.",display_name:"تأثيرات فيديو كليغ",inputs:{duration:{name:"المدة"},effect_scene:{name:"مشهد التأثير"},image:{name:"صورة مرجعية",tooltip:"صورة مرجعية. رابط أو نص مشفر Base64 (بدون بادئة data:image). لا يتجاوز حجم الملف 10 ميغابايت، الدقة لا تقل عن 300×300 بكسل، نسبة العرض إلى الارتفاع بين 1:2.5 و2.5:1"},model_name:{name:"اسم النموذج"}},outputs:{1:{name:"معرّف الفيديو"},2:{name:"المدة"}}},Dn={description:"إنشاء تسلسل فيديو ينتقل بين صور البداية والنهاية التي تزودها. يقوم العقد بإنشاء جميع الإطارات بينهما، مما ينتج تحولًا سلسًا من الإطار الأول إلى الأخير.",display_name:"كليينج إطار البداية-النهاية إلى فيديو",inputs:{aspect_ratio:{name:"aspect_ratio"},cfg_scale:{name:"cfg_scale"},end_frame:{name:"end_frame",tooltip:"صورة مرجعية - تحكم إطار النهاية. رابط URL أو نص مشفر بصيغة Base64، لا يتجاوز 10 ميجابايت، الدقة لا تقل عن 300*300 بكسل. يجب ألا يتضمن نص Base64 بادئة data:image."},mode:{name:"mode",tooltip:"التكوين المستخدم لتوليد الفيديو وفقًا للصيغة: الوضع / المدة / اسم النموذج."},negative_prompt:{name:"negative_prompt",tooltip:"نص سلبي للتوجيه"},prompt:{name:"prompt",tooltip:"نص إيجابي للتوجيه"},start_frame:{name:"start_frame",tooltip:"صورة مرجعية - رابط URL أو نص مشفر بصيغة Base64، لا يتجاوز 10 ميجابايت، الدقة لا تقل عن 300*300 بكسل، نسبة العرض إلى الارتفاع بين 1:2.5 ~ 2.5:1. يجب ألا يتضمن نص Base64 بادئة data:image."}},outputs:{1:{name:"video_id"},2:{name:"duration"}}},Nn={description:"عقدة تحويل النص إلى فيديو من كليينج",display_name:"كليينج تحويل النص إلى فيديو",inputs:{aspect_ratio:{name:"aspect_ratio"},cfg_scale:{name:"cfg_scale"},mode:{name:"mode",tooltip:"التكوين المستخدم لتوليد الفيديو وفقًا للصيغة: الوضع / المدة / اسم النموذج."},negative_prompt:{name:"negative_prompt",tooltip:"نص سلبي للتوجيه"},prompt:{name:"prompt",tooltip:"نص إيجابي للتوجيه"}},outputs:{1:{name:"video_id"},2:{name:"duration"}}},Gn={description:"عقدة تمديد الفيديو من كليينج. تمديد الفيديوهات المصنوعة بواسطة عقد كليينج الأخرى. يتم إنشاء video_id باستخدام عقد كليينج الأخرى.",display_name:"كليينج تمديد الفيديو",inputs:{cfg_scale:{name:"cfg_scale"},negative_prompt:{name:"negative_prompt",tooltip:"نص سلبي لعناصر يجب تجنبها في الفيديو الممدد"},prompt:{name:"prompt",tooltip:"نص إيجابي لتوجيه تمديد الفيديو"},video_id:{name:"video_id",tooltip:"معرف الفيديو المراد تمديده. يدعم الفيديوهات الناتجة عن تحويل النص إلى فيديو، وتحويل الصورة إلى فيديو، وعمليات تمديد الفيديو السابقة. لا يمكن أن تتجاوز مدة الفيديو الإجمالية بعد التمديد 3 دقائق."}},outputs:{1:{name:"video_id"},2:{name:"duration"}}},Fn={description:"عقدة تجربة الملابس الافتراضية من كليينج. أدخل صورة إنسان وصورة ملابس لتجربة الملابس على الإنسان.",display_name:"كليينج تجربة الملابس الافتراضية",inputs:{cloth_image:{name:"cloth_image"},human_image:{name:"human_image"},model_name:{name:"model_name"}}},Rn={display_name:"إضافة دليل LTXV",inputs:{frame_idx:{name:"مؤشر الإطار",tooltip:"مؤشر الإطار لبدء التهيئة. لأي صورة أو فيديو بإطارات 1-8، أي قيمة مقبولة. للفيديوهات 9+، يجب أن يكون قابلاً للقسمة على 8، وإلا سيتم تقريبه للأسفل لأقرب مضاعف 8. القيم السالبة تُحسب من نهاية الفيديو."},image:{name:"صورة",tooltip:"صورة أو فيديو لتكييف الفيديو الكامن عليه. يجب أن يكون عدد الإطارات 8*n + 1. إذا لم يكن كذلك، سيتم قصه إلى أقرب 8*n + 1."},latent:{name:"كامن"},negative:{name:"سلبي"},positive:{name:"إيجابي"},strength:{name:"القوة"},vae:{name:"VAE"}},outputs:{0:{name:"إيجابي"},1:{name:"سلبي"},2:{name:"كامن"}}},Bn={display_name:"تهيئة LTXV",inputs:{frame_rate:{name:"معدل الإطارات"},negative:{name:"سلبي"},positive:{name:"إيجابي"}},outputs:{0:{name:"إيجابي"},1:{name:"سلبي"}}},wn={display_name:"قص أدلة LTXV",inputs:{latent:{name:"كامن"},negative:{name:"سلبي"},positive:{name:"إيجابي"}},outputs:{0:{name:"إيجابي"},1:{name:"سلبي"},2:{name:"كامن"}}},Un={display_name:"LTXV صورة إلى فيديو",inputs:{batch_size:{name:"حجم الدُفعة"},height:{name:"الارتفاع"},image:{name:"صورة"},length:{name:"الطول"},negative:{name:"سلبي"},positive:{name:"إيجابي"},strength:{name:"القوة"},vae:{name:"vae"},width:{name:"العرض"}},outputs:{0:{name:"إيجابي"},1:{name:"سلبي"},2:{name:"كامن"}}},jn={display_name:"LTXV المعالجة المسبقة",inputs:{image:{name:"صورة"},img_compression:{name:"ضغط الصورة",tooltip:"مقدار الضغط الذي سيتم تطبيقه على الصورة."}},outputs:{0:{name:"صورة الإخراج"}}},Hn={display_name:"LTXV المجدول",inputs:{base_shift:{name:"الانزياح الأساسي"},latent:{name:"كامن"},max_shift:{name:"الانزياح الأقصى"},steps:{name:"خطوات"},stretch:{name:"تمدد",tooltip:"تمديد قيم السيغما لتكون ضمن المدى [النهائي، 1]."},terminal:{name:"نهائي",tooltip:"القيمة النهائية للسيغما بعد التمدد."}}},Xn={display_name:"جدول لاپلاس",inputs:{beta:{name:"beta"},mu:{name:"mu"},sigma_max:{name:"sigma_max"},sigma_min:{name:"sigma_min"},steps:{name:"الخطوات"}}},zn={display_name:"جمع الكامن",inputs:{samples1:{name:"samples1"},samples2:{name:"samples2"}}},Kn={display_name:"تطبيق عملية على الكامن",inputs:{operation:{name:"operation"},samples:{name:"samples"}}},On={display_name:"تطبيق عملية مع CFG على الكامن",inputs:{model:{name:"model"},operation:{name:"operation"}}},Wn={display_name:"دفعة كامن",inputs:{samples1:{name:"samples1"},samples2:{name:"samples2"}}},Yn={display_name:"سلوك بذرة دفعة الكامن",inputs:{samples:{name:"samples"},seed_behavior:{name:"seed_behavior"}}},qn={display_name:"مزج الكامن",inputs:{blend_factor:{name:"blend_factor"},samples1:{name:"samples1"},samples2:{name:"samples2"}}},Zn={display_name:"تركيب الكامن",inputs:{feather:{name:"feather"},samples_from:{name:"samples_from"},samples_to:{name:"samples_to"},x:{name:"x"},y:{name:"y"}}},Qn={display_name:"تركيب كامن مقنع",inputs:{destination:{name:"destination"},mask:{name:"mask"},resize_source:{name:"resize_source"},source:{name:"source"},x:{name:"x"},y:{name:"y"}}},Jn={display_name:"قص الكامن",inputs:{height:{name:"height"},samples:{name:"samples"},width:{name:"width"},x:{name:"x"},y:{name:"y"}}},$n={display_name:"قلب الكامن",inputs:{flip_method:{name:"flip_method"},samples:{name:"samples"}}},ea={display_name:"الكامن من الدفعة",inputs:{batch_index:{name:"batch_index"},length:{name:"length"},samples:{name:"samples"}}},na={display_name:"استيفاء الكامن",inputs:{ratio:{name:"ratio"},samples1:{name:"samples1"},samples2:{name:"samples2"}}},aa={display_name:"الضرب الكامن",inputs:{multiplier:{name:"المضاعف"},samples:{name:"عينات"}}},ta={display_name:"عملية التوضيح الكامن",inputs:{alpha:{name:"ألفا"},sharpen_radius:{name:"نصف قطر التوضيح"},sigma:{name:"سيغما"}}},oa={display_name:"عملية خريطة اللون الكامنة - راينهارد",inputs:{multiplier:{name:"المضاعف"}}},ma={display_name:"تدوير كامن",inputs:{rotation:{name:"التدوير"},samples:{name:"عينات"}}},ia={display_name:"طرح كامن",inputs:{samples1:{name:"عينات 1"},samples2:{name:"عينات 2"}}},sa={display_name:"تكبير كامن",inputs:{crop:{name:"قص"},height:{name:"الارتفاع"},samples:{name:"عينات"},upscale_method:{name:"طريقة التكبير"},width:{name:"العرض"}}},_a={display_name:"تكبير كامن بنسبة",inputs:{samples:{name:"عينات"},scale_by:{name:"نسبة التكبير"},upscale_method:{name:"طريقة التكبير"}}},la={display_name:"تحميل ثلاثي الأبعاد",inputs:{clear:{},height:{name:"الارتفاع"},image:{name:"صورة"},model_file:{name:"ملف النموذج"},"upload 3d model":{},width:{name:"العرض"}},outputs:{0:{name:"صورة"},1:{name:"قناع"},2:{name:"مسار الشبكة"},3:{name:"المعتاد"},4:{name:"الخطوط"},5:{name:"معلومات الكاميرا"}}},pa={display_name:"تحميل ثلاثي الأبعاد - حركة",inputs:{height:{name:"الارتفاع"},image:{name:"صورة"},model_file:{name:"ملف النموذج"},width:{name:"العرض"}},outputs:{0:{name:"صورة"},1:{name:"قناع"},2:{name:"مسار الشبكة"},3:{name:"المعتاد"},4:{name:"معلومات الكاميرا"}}},ca={display_name:"تحميل الصوت",inputs:{audio:{name:"صوت"},audioUI:{name:"واجهة الصوت"},upload:{name:"اختر ملف للتحميل"}}},da={display_name:"تحميل صورة",inputs:{image:{name:"صورة"},upload:{name:"اختر ملف للتحميل"}}},ra={display_name:"تحميل صورة (كقناع)",inputs:{channel:{name:"القناة"},image:{name:"صورة"},upload:{name:"اختر ملف للتحميل"}}},ua={description:"تحميل صورة من مجلد المخرجات. عند الضغط على زر التحديث، سيقوم العقدة بتحديث قائمة الصور واختيار أول صورة تلقائياً لتسهيل التكرار.",display_name:"تحميل صورة (من المخرجات)",inputs:{image:{name:"صورة"},refresh:{},upload:{name:"اختر ملف للتحميل"}}},ga={display_name:"تحميل كامن",inputs:{latent:{name:"كامن"}}},ba={display_name:"تحميل فيديو",inputs:{file:{name:"ملف"},upload:{name:"اختر ملف للتحميل"}}},ya={description:"يُستخدم LoRA لتعديل نماذج الانتشار و CLIP، وتغيير طريقة إزالة الضجيج من الكامن مثل تطبيق الأنماط. يمكن ربط عدة عقد LoRA معاً.",display_name:"تحميل LoRA",inputs:{clip:{name:"CLIP",tooltip:"نموذج CLIP الذي سيتم تطبيق LoRA عليه."},lora_name:{name:"اسم LoRA",tooltip:"اسم LoRA."},model:{name:"النموذج",tooltip:"نموذج الانتشار الذي سيتم تطبيق LoRA عليه."},strength_clip:{name:"قوة تعديل CLIP",tooltip:"مدى قوة تعديل نموذج CLIP. يمكن أن تكون القيمة سالبة."},strength_model:{name:"قوة تعديل النموذج",tooltip:"مدى قوة تعديل نموذج الانتشار. يمكن أن تكون القيمة سالبة."}},outputs:{0:{tooltip:"نموذج الانتشار المعدل."},1:{tooltip:"نموذج CLIP المعدل."}}},ka={description:"يُستخدم LoRA لتعديل نماذج الانتشار و CLIP، وتغيير طريقة إزالة الضجيج من الكامن مثل تطبيق الأنماط. يمكن ربط عدة عقد LoRA معاً.",display_name:"تحميل LoRA (نموذج فقط)",inputs:{lora_name:{name:"اسم LoRA"},model:{name:"النموذج"},strength_model:{name:"قوة تعديل النموذج"}},outputs:{0:{tooltip:"نموذج الانتشار المعدل."}}},ha={display_name:"استخراج وحفظ LoRA",inputs:{bias_diff:{name:"فرق الانحياز"},filename_prefix:{name:"بادئة اسم الملف"},lora_type:{name:"نوع LoRA"},model_diff:{name:"فرق النموذج",tooltip:"مخرج ModelSubtract الذي سيتم تحويله إلى LoRA."},rank:{name:"الرتبة"},text_encoder_diff:{name:"فرق مشفر النص",tooltip:"مخرج CLIPSubtract الذي سيتم تحويله إلى LoRA."}}},La={display_name:"تهيئة Lotus",outputs:{0:{name:"تهيئة"}}},Ca={description:"يحتوي على مفهوم كاميرا واحد أو أكثر للاستخدام مع Luma نص إلى فيديو وLuma صورة إلى فيديو.",display_name:"مفاهيم لومة",inputs:{concept1:{name:"المفهوم 1"},concept2:{name:"المفهوم 2"},concept3:{name:"المفهوم 3"},concept4:{name:"المفهوم 4"},luma_concepts:{name:"مفاهيم لومة",tooltip:"مفاهيم كاميرا اختيارية لإضافتها إلى المفاهيم المختارة هنا."}},outputs:{0:{name:"مفاهيم لومة"}}},Sa={description:"تعديل الصور بشكل متزامن بناءً على النص المطلوب ونسبة العرض إلى الارتفاع.",display_name:"Luma صورة إلى صورة",inputs:{control_after_generate:{name:"التحكم بعد التوليد"},image:{name:"صورة"},image_weight:{name:"وزن الصورة",tooltip:"وزن الصورة؛ كلما اقترب من 1.0، كان التعديل أقل على الصورة."},model:{name:"نموذج"},prompt:{name:"النص المطلوب",tooltip:"النص المطلوب لتوليد الصورة"},seed:{name:"البذرة",tooltip:"تُستخدم لتحديد ما إذا كان يجب إعادة تشغيل العقدة؛ النتائج الفعلية غير حتمية بغض النظر عن البذرة."}}},fa={description:"توليد الصور بشكل متزامن بناءً على النص المطلوب ونسبة العرض إلى الارتفاع.",display_name:"Luma نص إلى صورة",inputs:{aspect_ratio:{name:"نسبة العرض إلى الارتفاع"},character_image:{name:"صورة الشخصية",tooltip:"صور مرجعية للشخصية؛ يمكن أن تكون دفعة متعددة، حتى 4 صور يمكن اعتبارها."},control_after_generate:{name:"التحكم بعد التوليد"},image_luma_ref:{name:"مرجع لومة للصورة",tooltip:"اتصال عقدة مرجع لومة للتأثير على التوليد باستخدام الصور المدخلة؛ يمكن اعتبار ما يصل إلى 4 صور."},model:{name:"نموذج"},prompt:{name:"النص المطلوب",tooltip:"النص المطلوب لتوليد الصورة"},seed:{name:"البذرة",tooltip:"تُستخدم لتحديد ما إذا كان يجب إعادة تشغيل العقدة؛ النتائج الفعلية غير حتمية بغض النظر عن البذرة."},style_image:{name:"صورة النمط",tooltip:"صورة مرجعية للنمط؛ سيتم استخدام صورة واحدة فقط."},style_image_weight:{name:"وزن صورة النمط",tooltip:"وزن صورة النمط. يتم تجاهله إذا لم يتم توفير صورة نمط."}}},va={description:"توليد الفيديوهات بشكل متزامن بناءً على النص المطلوب، الصور المدخلة، وحجم الإخراج.",display_name:"Luma صورة إلى فيديو",inputs:{control_after_generate:{name:"التحكم بعد التوليد"},duration:{name:"المدة"},first_image:{name:"الصورة الأولى",tooltip:"الإطار الأول من الفيديو المولد."},last_image:{name:"الصورة الأخيرة",tooltip:"الإطار الأخير من الفيديو المولد."},loop:{name:"التكرار"},luma_concepts:{name:"مفاهيم لومة",tooltip:"مفاهيم كاميرا اختيارية لتوجيه حركة الكاميرا عبر عقدة مفاهيم لومة."},model:{name:"نموذج"},prompt:{name:"النص المطلوب",tooltip:"النص المطلوب لتوليد الفيديو"},resolution:{name:"الدقة"},seed:{name:"البذرة",tooltip:"تُستخدم لتحديد ما إذا كان يجب إعادة تشغيل العقدة؛ النتائج الفعلية غير حتمية بغض النظر عن البذرة."}}},Ia={description:"يحتوي على صورة ووزن لاستخدامها مع عقدة توليد صورة لومة.",display_name:"مرجع لومة",inputs:{image:{name:"صورة",tooltip:"صورة لاستخدامها كمرجع."},luma_ref:{name:"مرجع لومة"},weight:{name:"الوزن",tooltip:"وزن صورة المرجع."}},outputs:{0:{name:"مرجع لومة"}}},Pa={description:"توليد الفيديوهات بشكل متزامن بناءً على النص المطلوب وحجم الإخراج.",display_name:"Luma نص إلى فيديو",inputs:{aspect_ratio:{name:"نسبة العرض إلى الارتفاع"},control_after_generate:{name:"التحكم بعد التوليد"},duration:{name:"المدة"},loop:{name:"التكرار"},luma_concepts:{name:"مفاهيم لومة",tooltip:"مفاهيم كاميرا اختيارية لتوجيه حركة الكاميرا عبر عقدة مفاهيم لومة."},model:{name:"نموذج"},prompt:{name:"النص المطلوب",tooltip:"النص المطلوب لتوليد الفيديو"},resolution:{name:"الدقة"},seed:{name:"البذرة",tooltip:"تُستخدم لتحديد ما إذا كان يجب إعادة تشغيل العقدة؛ النتائج الفعلية غير حتمية بغض النظر عن البذرة."}}},Ma={description:"تعديل التوجيه للتركيز أكثر على 'اتجاه' النص الإيجابي بدلاً من الفرق بين النص السلبي.",display_name:"ماهيرو لطيفة جداً وتستحق دالة توجيه أفضل!! (。・ω・。)",inputs:{model:{name:"نموذج"}},outputs:{0:{name:"نموذج مُعدل"}}},Aa={display_name:"تركيب القناع",inputs:{destination:{name:"الوجهة"},operation:{name:"عملية"},source:{name:"المصدر"},x:{name:"س"},y:{name:"ص"}}},Va={description:"يحفظ الصور المدخلة في مجلد الإخراج الخاص بـ ComfyUI.",display_name:"معاينة القناع",inputs:{mask:{name:"قناع"}}},xa={display_name:"تحويل القناع إلى صورة",inputs:{mask:{name:"قناع"}}},Ta={description:"توليد فيديوهات من صورة ونصوص باستخدام API الخاص بـ MiniMax",display_name:"MiniMax صورة إلى فيديو",inputs:{control_after_generate:{name:"التحكم بعد التوليد"},image:{name:"صورة",tooltip:"الصورة لاستخدامها كالإطار الأول من الفيديو"},model:{name:"نموذج",tooltip:"النموذج المستخدم لتوليد الفيديو"},prompt_text:{name:"نص النص المطلوب",tooltip:"نص لتوجيه توليد الفيديو"},seed:{name:"بذرة",tooltip:"البذرة العشوائية المستخدمة لإنشاء الضجيج."}}},Ea={description:"توليد فيديوهات من نصوص باستخدام API الخاص بـ MiniMax",display_name:"MiniMax نص إلى فيديو",inputs:{control_after_generate:{name:"التحكم بعد التوليد"},model:{name:"نموذج",tooltip:"النموذج المستخدم لتوليد الفيديو"},prompt_text:{name:"نص النص المطلوب",tooltip:"نص لتوجيه توليد الفيديو"},seed:{name:"بذرة",tooltip:"البذرة العشوائية المستخدمة لإنشاء الضجيج."}}},Da={display_name:"نوع بيانات حساب النموذج",inputs:{dtype:{name:"نوع البيانات"},model:{name:"نموذج"}}},Na={display_name:"دمج النموذج بإضافة",inputs:{model1:{name:"نموذج 1"},model2:{name:"نموذج 2"}}},Ga={display_name:"دمج_النموذج_أورافلو",inputs:{cond_seq_linear_:{name:"تسلسل_شرطي_خطي"},double_layers_0_:{name:"طبقات_مزدوجة.0"},double_layers_1_:{name:"طبقات_مزدوجة.1"},double_layers_2_:{name:"طبقات_مزدوجة.2"},double_layers_3_:{name:"طبقات_مزدوجة.3"},final_linear_:{name:"الخطي_النهائي"},init_x_linear_:{name:"المُبادرة_الخطيه_x"},modF_:{name:"مُعدلF"},model1:{name:"النموذج1"},model2:{name:"النموذج2"},positional_encoding:{name:"ترميز_موضعي"},register_tokens:{name:"تسجيل_الرموز"},single_layers_0_:{name:"طبقات_مفردة.0"},single_layers_10_:{name:"طبقات_مفردة.10"},single_layers_11_:{name:"طبقات_مفردة.11"},single_layers_12_:{name:"طبقات_مفردة.12"},single_layers_13_:{name:"طبقات_مفردة.13"},single_layers_14_:{name:"طبقات_مفردة.14"},single_layers_15_:{name:"طبقات_مفردة.15"},single_layers_16_:{name:"طبقات_مفردة.16"},single_layers_17_:{name:"طبقات_مفردة.17"},single_layers_18_:{name:"طبقات_مفردة.18"},single_layers_19_:{name:"طبقات_مفردة.19"},single_layers_1_:{name:"طبقات_مفردة.1"},single_layers_20_:{name:"طبقات_مفردة.20"},single_layers_21_:{name:"طبقات_مفردة.21"},single_layers_22_:{name:"طبقات_مفردة.22"},single_layers_23_:{name:"طبقات_مفردة.23"},single_layers_24_:{name:"طبقات_مفردة.24"},single_layers_25_:{name:"طبقات_مفردة.25"},single_layers_26_:{name:"طبقات_مفردة.26"},single_layers_27_:{name:"طبقات_مفردة.27"},single_layers_28_:{name:"طبقات_مفردة.28"},single_layers_29_:{name:"طبقات_مفردة.29"},single_layers_2_:{name:"طبقات_مفردة.2"},single_layers_30_:{name:"طبقات_مفردة.30"},single_layers_31_:{name:"طبقات_مفردة.31"},single_layers_3_:{name:"طبقات_مفردة.3"},single_layers_4_:{name:"طبقات_مفردة.4"},single_layers_5_:{name:"طبقات_مفردة.5"},single_layers_6_:{name:"طبقات_مفردة.6"},single_layers_7_:{name:"طبقات_مفردة.7"},single_layers_8_:{name:"طبقات_مفردة.8"},single_layers_9_:{name:"طبقات_مفردة.9"},t_embedder_:{name:"مضمن_t"}}},Fa={display_name:"دمج_كتل_النموذج",inputs:{input:{name:"الإدخال"},middle:{name:"الوسط"},model1:{name:"النموذج1"},model2:{name:"النموذج2"},out:{name:"الإخراج"}}},Ra={display_name:"دمج_نموذج_كوزموس14B",inputs:{affline_norm_:{name:"تطبيع_تحويلي"},blocks_block0_:{name:"كتل.كتلة0"},blocks_block10_:{name:"كتل.كتلة10"},blocks_block11_:{name:"كتل.كتلة11"},blocks_block12_:{name:"كتل.كتلة12"},blocks_block13_:{name:"كتل.كتلة13"},blocks_block14_:{name:"كتل.كتلة14"},blocks_block15_:{name:"كتل.كتلة15"},blocks_block16_:{name:"كتل.كتلة16"},blocks_block17_:{name:"كتل.كتلة17"},blocks_block18_:{name:"كتل.كتلة18"},blocks_block19_:{name:"كتل.كتلة19"},blocks_block1_:{name:"كتل.كتلة1"},blocks_block20_:{name:"كتل.كتلة20"},blocks_block21_:{name:"كتل.كتلة21"},blocks_block22_:{name:"كتل.كتلة22"},blocks_block23_:{name:"كتل.كتلة23"},blocks_block24_:{name:"كتل.كتلة24"},blocks_block25_:{name:"كتل.كتلة25"},blocks_block26_:{name:"كتل.كتلة26"},blocks_block27_:{name:"كتل.كتلة27"},blocks_block28_:{name:"كتل.كتلة28"},blocks_block29_:{name:"كتل.كتلة29"},blocks_block2_:{name:"كتل.كتلة2"},blocks_block30_:{name:"كتل.كتلة30"},blocks_block31_:{name:"كتل.كتلة31"},blocks_block32_:{name:"كتل.كتلة32"},blocks_block33_:{name:"كتل.كتلة33"},blocks_block34_:{name:"كتل.كتلة34"},blocks_block35_:{name:"كتل.كتلة35"},blocks_block3_:{name:"كتل.كتلة3"},blocks_block4_:{name:"كتل.كتلة4"},blocks_block5_:{name:"كتل.كتلة5"},blocks_block6_:{name:"كتل.كتلة6"},blocks_block7_:{name:"كتل.كتلة7"},blocks_block8_:{name:"كتل.كتلة8"},blocks_block9_:{name:"كتل.كتلة9"},extra_pos_embedder_:{name:"مضمن_موقع_إضافي"},final_layer_:{name:"الطبقة_النهائية"},model1:{name:"النموذج1"},model2:{name:"النموذج2"},pos_embedder_:{name:"مضمن_الموقع"},t_embedder_:{name:"مضمن_t"},x_embedder_:{name:"مضمن_x"}}},Ba={display_name:"دمج_نموذج_كوزموس7B",inputs:{affline_norm_:{name:"تطبيع_تحويلي"},blocks_block0_:{name:"كتل.كتلة0"},blocks_block10_:{name:"كتل.كتلة10"},blocks_block11_:{name:"كتل.كتلة11"},blocks_block12_:{name:"كتل.كتلة12"},blocks_block13_:{name:"كتل.كتلة13"},blocks_block14_:{name:"كتل.كتلة14"},blocks_block15_:{name:"كتل.كتلة15"},blocks_block16_:{name:"كتل.كتلة16"},blocks_block17_:{name:"كتل.كتلة17"},blocks_block18_:{name:"كتل.كتلة18"},blocks_block19_:{name:"كتل.كتلة19"},blocks_block1_:{name:"كتل.كتلة1"},blocks_block20_:{name:"كتل.كتلة20"},blocks_block21_:{name:"كتل.كتلة21"},blocks_block22_:{name:"كتل.كتلة22"},blocks_block23_:{name:"كتل.كتلة23"},blocks_block24_:{name:"كتل.كتلة24"},blocks_block25_:{name:"كتل.كتلة25"},blocks_block26_:{name:"كتل.كتلة26"},blocks_block27_:{name:"كتل.كتلة27"},blocks_block2_:{name:"كتل.كتلة2"},blocks_block3_:{name:"كتل.كتلة3"},blocks_block4_:{name:"كتل.كتلة4"},blocks_block5_:{name:"كتل.كتلة5"},blocks_block6_:{name:"كتل.كتلة6"},blocks_block7_:{name:"كتل.كتلة7"},blocks_block8_:{name:"كتل.كتلة8"},blocks_block9_:{name:"كتل.كتلة9"},extra_pos_embedder_:{name:"مضمن_موقع_إضافي"},final_layer_:{name:"الطبقة_النهائية"},model1:{name:"النموذج1"},model2:{name:"النموذج2"},pos_embedder_:{name:"مضمن_الموقع"},t_embedder_:{name:"مضمن_t"},x_embedder_:{name:"مضمن_x"}}},wa={display_name:"ModelMergeFlux1",inputs:{double_blocks_0_:{name:"كتل مزدوجة 0"},double_blocks_10_:{name:"كتل مزدوجة 10"},double_blocks_11_:{name:"كتل مزدوجة 11"},double_blocks_12_:{name:"كتل مزدوجة 12"},double_blocks_13_:{name:"كتل مزدوجة 13"},double_blocks_14_:{name:"كتل مزدوجة 14"},double_blocks_15_:{name:"كتل مزدوجة 15"},double_blocks_16_:{name:"كتل مزدوجة 16"},double_blocks_17_:{name:"كتل مزدوجة 17"},double_blocks_18_:{name:"كتل مزدوجة 18"},double_blocks_1_:{name:"كتل مزدوجة 1"},double_blocks_2_:{name:"كتل مزدوجة 2"},double_blocks_3_:{name:"كتل مزدوجة 3"},double_blocks_4_:{name:"كتل مزدوجة 4"},double_blocks_5_:{name:"كتل مزدوجة 5"},double_blocks_6_:{name:"كتل مزدوجة 6"},double_blocks_7_:{name:"كتل مزدوجة 7"},double_blocks_8_:{name:"كتل مزدوجة 8"},double_blocks_9_:{name:"كتل مزدوجة 9"},final_layer_:{name:"الطبقة النهائية"},guidance_in:{name:"توجيه الإدخال"},img_in_:{name:"صورة الإدخال"},model1:{name:"النموذج 1"},model2:{name:"النموذج 2"},single_blocks_0_:{name:"كتل فردية 0"},single_blocks_10_:{name:"كتل فردية 10"},single_blocks_11_:{name:"كتل فردية 11"},single_blocks_12_:{name:"كتل فردية 12"},single_blocks_13_:{name:"كتل فردية 13"},single_blocks_14_:{name:"كتل فردية 14"},single_blocks_15_:{name:"كتل فردية 15"},single_blocks_16_:{name:"كتل فردية 16"},single_blocks_17_:{name:"كتل فردية 17"},single_blocks_18_:{name:"كتل فردية 18"},single_blocks_19_:{name:"كتل فردية 19"},single_blocks_1_:{name:"كتل فردية 1"},single_blocks_20_:{name:"كتل فردية 20"},single_blocks_21_:{name:"كتل فردية 21"},single_blocks_22_:{name:"كتل فردية 22"},single_blocks_23_:{name:"كتل فردية 23"},single_blocks_24_:{name:"كتل فردية 24"},single_blocks_25_:{name:"كتل فردية 25"},single_blocks_26_:{name:"كتل فردية 26"},single_blocks_27_:{name:"كتل فردية 27"},single_blocks_28_:{name:"كتل فردية 28"},single_blocks_29_:{name:"كتل فردية 29"},single_blocks_2_:{name:"كتل فردية 2"},single_blocks_30_:{name:"كتل فردية 30"},single_blocks_31_:{name:"كتل فردية 31"},single_blocks_32_:{name:"كتل فردية 32"},single_blocks_33_:{name:"كتل فردية 33"},single_blocks_34_:{name:"كتل فردية 34"},single_blocks_35_:{name:"كتل فردية 35"},single_blocks_36_:{name:"كتل فردية 36"},single_blocks_37_:{name:"كتل فردية 37"},single_blocks_3_:{name:"كتل فردية 3"},single_blocks_4_:{name:"كتل فردية 4"},single_blocks_5_:{name:"كتل فردية 5"},single_blocks_6_:{name:"كتل فردية 6"},single_blocks_7_:{name:"كتل فردية 7"},single_blocks_8_:{name:"كتل فردية 8"},single_blocks_9_:{name:"كتل فردية 9"},time_in_:{name:"وقت الإدخال"},txt_in_:{name:"نص الإدخال"},vector_in_:{name:"متجه الإدخال"}}},Ua={display_name:"ModelMergeLTXV",inputs:{adaln_single_:{name:"آدال إن الفردي"},caption_projection_:{name:"إسقاط التسمية التوضيحية"},model1:{name:"النموذج 1"},model2:{name:"النموذج 2"},patchify_proj_:{name:"مشروع التقسيم"},proj_out_:{name:"الإسقاط الخارجي"},scale_shift_table:{name:"جدول تحجيم الإزاحة"},transformer_blocks_0_:{name:"كتل المحول 0"},transformer_blocks_10_:{name:"كتل المحول 10"},transformer_blocks_11_:{name:"كتل المحول 11"},transformer_blocks_12_:{name:"كتل المحول 12"},transformer_blocks_13_:{name:"كتل المحول 13"},transformer_blocks_14_:{name:"كتل المحول 14"},transformer_blocks_15_:{name:"كتل المحول 15"},transformer_blocks_16_:{name:"كتل المحول 16"},transformer_blocks_17_:{name:"كتل المحول 17"},transformer_blocks_18_:{name:"كتل المحول 18"},transformer_blocks_19_:{name:"كتل المحول 19"},transformer_blocks_1_:{name:"كتل المحول 1"},transformer_blocks_20_:{name:"كتل المحول 20"},transformer_blocks_21_:{name:"كتل المحول 21"},transformer_blocks_22_:{name:"كتل المحول 22"},transformer_blocks_23_:{name:"كتل المحول 23"},transformer_blocks_24_:{name:"كتل المحول 24"},transformer_blocks_25_:{name:"كتل المحول 25"},transformer_blocks_26_:{name:"كتل المحول 26"},transformer_blocks_27_:{name:"كتل المحول 27"},transformer_blocks_2_:{name:"كتل المحول 2"},transformer_blocks_3_:{name:"كتل المحول 3"},transformer_blocks_4_:{name:"كتل المحول 4"},transformer_blocks_5_:{name:"كتل المحول 5"},transformer_blocks_6_:{name:"كتل المحول 6"},transformer_blocks_7_:{name:"كتل المحول 7"},transformer_blocks_8_:{name:"كتل المحول 8"},transformer_blocks_9_:{name:"كتل المحول 9"}}},ja={display_name:"ModelMergeMochiPreview",inputs:{blocks_0_:{name:"كتل 0"},blocks_10_:{name:"كتل 10"},blocks_11_:{name:"كتل 11"},blocks_12_:{name:"كتل 12"},blocks_13_:{name:"كتل 13"},blocks_14_:{name:"كتل 14"},blocks_15_:{name:"كتل 15"},blocks_16_:{name:"كتل 16"},blocks_17_:{name:"كتل 17"},blocks_18_:{name:"كتل 18"},blocks_19_:{name:"كتل 19"},blocks_1_:{name:"كتل 1"},blocks_20_:{name:"كتل 20"},blocks_21_:{name:"كتل 21"},blocks_22_:{name:"كتل 22"},blocks_23_:{name:"كتل 23"},blocks_24_:{name:"كتل 24"},blocks_25_:{name:"كتل 25"},blocks_26_:{name:"كتل 26"},blocks_27_:{name:"كتل 27"},blocks_28_:{name:"كتل 28"},blocks_29_:{name:"كتل 29"},blocks_2_:{name:"كتل 2"},blocks_30_:{name:"كتل 30"},blocks_31_:{name:"كتل 31"},blocks_32_:{name:"كتل 32"},blocks_33_:{name:"كتل 33"},blocks_34_:{name:"كتل 34"},blocks_35_:{name:"كتل 35"},blocks_36_:{name:"كتل 36"},blocks_37_:{name:"كتل 37"},blocks_38_:{name:"كتل 38"},blocks_39_:{name:"كتل 39"},blocks_3_:{name:"كتل 3"},blocks_40_:{name:"كتل 40"},blocks_41_:{name:"كتل 41"},blocks_42_:{name:"كتل 42"},blocks_43_:{name:"كتل 43"},blocks_44_:{name:"كتل 44"},blocks_45_:{name:"كتل 45"},blocks_46_:{name:"كتل 46"},blocks_47_:{name:"كتل 47"},blocks_4_:{name:"كتل 4"},blocks_5_:{name:"كتل 5"},blocks_6_:{name:"كتل 6"},blocks_7_:{name:"كتل 7"},blocks_8_:{name:"كتل 8"},blocks_9_:{name:"كتل 9"},final_layer_:{name:"الطبقة النهائية"},model1:{name:"النموذج 1"},model2:{name:"النموذج 2"},pos_frequencies_:{name:"ترددات المواضع"},t5_y_embedder_:{name:"تضمين y لـ T5"},t5_yproj_:{name:"إسقاط y لـ T5"},t_embedder_:{name:"تضمين الزمن"}}},Ha={display_name:"دمج النموذج SD1",inputs:{input_blocks_0_:{name:"كتل الإدخال.0."},input_blocks_10_:{name:"كتل الإدخال.10."},input_blocks_11_:{name:"كتل الإدخال.11."},input_blocks_1_:{name:"كتل الإدخال.1."},input_blocks_2_:{name:"كتل الإدخال.2."},input_blocks_3_:{name:"كتل الإدخال.3."},input_blocks_4_:{name:"كتل الإدخال.4."},input_blocks_5_:{name:"كتل الإدخال.5."},input_blocks_6_:{name:"كتل الإدخال.6."},input_blocks_7_:{name:"كتل الإدخال.7."},input_blocks_8_:{name:"كتل الإدخال.8."},input_blocks_9_:{name:"كتل الإدخال.9."},label_emb_:{name:"تضمين التسمية."},middle_block_0_:{name:"كتلة الوسط.0."},middle_block_1_:{name:"كتلة الوسط.1."},middle_block_2_:{name:"كتلة الوسط.2."},model1:{name:"النموذج 1"},model2:{name:"النموذج 2"},out_:{name:"الإخراج."},output_blocks_0_:{name:"كتل الإخراج.0."},output_blocks_10_:{name:"كتل الإخراج.10."},output_blocks_11_:{name:"كتل الإخراج.11."},output_blocks_1_:{name:"كتل الإخراج.1."},output_blocks_2_:{name:"كتل الإخراج.2."},output_blocks_3_:{name:"كتل الإخراج.3."},output_blocks_4_:{name:"كتل الإخراج.4."},output_blocks_5_:{name:"كتل الإخراج.5."},output_blocks_6_:{name:"كتل الإخراج.6."},output_blocks_7_:{name:"كتل الإخراج.7."},output_blocks_8_:{name:"كتل الإخراج.8."},output_blocks_9_:{name:"كتل الإخراج.9."},time_embed_:{name:"تضمين الوقت."}}},Xa={display_name:"دمج النموذج SD2",inputs:{input_blocks_0_:{name:"كتل الإدخال.0."},input_blocks_10_:{name:"كتل الإدخال.10."},input_blocks_11_:{name:"كتل الإدخال.11."},input_blocks_1_:{name:"كتل الإدخال.1."},input_blocks_2_:{name:"كتل الإدخال.2."},input_blocks_3_:{name:"كتل الإدخال.3."},input_blocks_4_:{name:"كتل الإدخال.4."},input_blocks_5_:{name:"كتل الإدخال.5."},input_blocks_6_:{name:"كتل الإدخال.6."},input_blocks_7_:{name:"كتل الإدخال.7."},input_blocks_8_:{name:"كتل الإدخال.8."},input_blocks_9_:{name:"كتل الإدخال.9."},label_emb_:{name:"تضمين التسمية."},middle_block_0_:{name:"كتلة الوسط.0."},middle_block_1_:{name:"كتلة الوسط.1."},middle_block_2_:{name:"كتلة الوسط.2."},model1:{name:"النموذج 1"},model2:{name:"النموذج 2"},out_:{name:"الإخراج."},output_blocks_0_:{name:"كتل الإخراج.0."},output_blocks_10_:{name:"كتل الإخراج.10."},output_blocks_11_:{name:"كتل الإخراج.11."},output_blocks_1_:{name:"كتل الإخراج.1."},output_blocks_2_:{name:"كتل الإخراج.2."},output_blocks_3_:{name:"كتل الإخراج.3."},output_blocks_4_:{name:"كتل الإخراج.4."},output_blocks_5_:{name:"كتل الإخراج.5."},output_blocks_6_:{name:"كتل الإخراج.6."},output_blocks_7_:{name:"كتل الإخراج.7."},output_blocks_8_:{name:"كتل الإخراج.8."},output_blocks_9_:{name:"كتل الإخراج.9."},time_embed_:{name:"تضمين الوقت."}}},za={display_name:"دمج النموذج SD35_كبير",inputs:{context_embedder_:{name:"مُدمج السياق."},final_layer_:{name:"الطبقة النهائية."},joint_blocks_0_:{name:"كتل مشتركة.0."},joint_blocks_10_:{name:"كتل مشتركة.10."},joint_blocks_11_:{name:"كتل مشتركة.11."},joint_blocks_12_:{name:"كتل مشتركة.12."},joint_blocks_13_:{name:"كتل مشتركة.13."},joint_blocks_14_:{name:"كتل مشتركة.14."},joint_blocks_15_:{name:"كتل مشتركة.15."},joint_blocks_16_:{name:"كتل مشتركة.16."},joint_blocks_17_:{name:"كتل مشتركة.17."},joint_blocks_18_:{name:"كتل مشتركة.18."},joint_blocks_19_:{name:"كتل مشتركة.19."},joint_blocks_1_:{name:"كتل مشتركة.1."},joint_blocks_20_:{name:"كتل مشتركة.20."},joint_blocks_21_:{name:"كتل مشتركة.21."},joint_blocks_22_:{name:"كتل مشتركة.22."},joint_blocks_23_:{name:"كتل مشتركة.23."},joint_blocks_24_:{name:"كتل مشتركة.24."},joint_blocks_25_:{name:"كتل مشتركة.25."},joint_blocks_26_:{name:"كتل مشتركة.26."},joint_blocks_27_:{name:"كتل مشتركة.27."},joint_blocks_28_:{name:"كتل مشتركة.28."},joint_blocks_29_:{name:"كتل مشتركة.29."},joint_blocks_2_:{name:"كتل مشتركة.2."},joint_blocks_30_:{name:"كتل مشتركة.30."},joint_blocks_31_:{name:"كتل مشتركة.31."},joint_blocks_32_:{name:"كتل مشتركة.32."},joint_blocks_33_:{name:"كتل مشتركة.33."},joint_blocks_34_:{name:"كتل مشتركة.34."},joint_blocks_35_:{name:"كتل مشتركة.35."},joint_blocks_36_:{name:"كتل مشتركة.36."},joint_blocks_37_:{name:"كتل مشتركة.37."},joint_blocks_3_:{name:"كتل مشتركة.3."},joint_blocks_4_:{name:"كتل مشتركة.4."},joint_blocks_5_:{name:"كتل مشتركة.5."},joint_blocks_6_:{name:"كتل مشتركة.6."},joint_blocks_7_:{name:"كتل مشتركة.7."},joint_blocks_8_:{name:"كتل مشتركة.8."},joint_blocks_9_:{name:"كتل مشتركة.9."},model1:{name:"النموذج 1"},model2:{name:"النموذج 2"},pos_embed_:{name:"تضمين الموضع."},t_embedder_:{name:"مُدمج T."},x_embedder_:{name:"مُدمج X."},y_embedder_:{name:"مُدمج Y."}}},Ka={display_name:"دمج النموذج SD3_2B",inputs:{context_embedder_:{name:"مُدمج السياق."},final_layer_:{name:"الطبقة النهائية."},joint_blocks_0_:{name:"كتل مشتركة.0."},joint_blocks_10_:{name:"كتل مشتركة.10."},joint_blocks_11_:{name:"كتل مشتركة.11."},joint_blocks_12_:{name:"كتل مشتركة.12."},joint_blocks_13_:{name:"كتل مشتركة.13."},joint_blocks_14_:{name:"كتل مشتركة.14."},joint_blocks_15_:{name:"كتل مشتركة.15."},joint_blocks_16_:{name:"كتل مشتركة.16."},joint_blocks_17_:{name:"كتل مشتركة.17."},joint_blocks_18_:{name:"كتل مشتركة.18."},joint_blocks_19_:{name:"كتل مشتركة.19."},joint_blocks_1_:{name:"كتل مشتركة.1."},joint_blocks_20_:{name:"كتل مشتركة.20."},joint_blocks_21_:{name:"كتل مشتركة.21."},joint_blocks_22_:{name:"كتل مشتركة.22."},joint_blocks_23_:{name:"كتل مشتركة.23."},joint_blocks_2_:{name:"كتل مشتركة.2."},joint_blocks_3_:{name:"كتل مشتركة.3."},joint_blocks_4_:{name:"كتل مشتركة.4."},joint_blocks_5_:{name:"كتل مشتركة.5."},joint_blocks_6_:{name:"كتل مشتركة.6."},joint_blocks_7_:{name:"كتل مشتركة.7."},joint_blocks_8_:{name:"كتل مشتركة.8."},joint_blocks_9_:{name:"كتل مشتركة.9."},model1:{name:"النموذج 1"},model2:{name:"النموذج 2"},pos_embed_:{name:"تضمين الموضع."},t_embedder_:{name:"مُدمج T."},x_embedder_:{name:"مُدمج X."},y_embedder_:{name:"مُدمج Y."}}},Oa={display_name:"دمج النموذج SDXL",inputs:{input_blocks_0:{name:"كتل الإدخال.0"},input_blocks_1:{name:"كتل الإدخال.1"},input_blocks_2:{name:"كتل الإدخال.2"},input_blocks_3:{name:"كتل الإدخال.3"},input_blocks_4:{name:"كتل الإدخال.4"},input_blocks_5:{name:"كتل الإدخال.5"},input_blocks_6:{name:"كتل الإدخال.6"},input_blocks_7:{name:"كتل الإدخال.7"},input_blocks_8:{name:"كتل الإدخال.8"},label_emb_:{name:"تضمين التسمية."},middle_block_0:{name:"الكتلة الوسطى.0"},middle_block_1:{name:"الكتلة الوسطى.1"},middle_block_2:{name:"الكتلة الوسطى.2"},model1:{name:"النموذج 1"},model2:{name:"النموذج 2"},out_:{name:"الخارج."},output_blocks_0:{name:"كتل الإخراج.0"},output_blocks_1:{name:"كتل الإخراج.1"},output_blocks_2:{name:"كتل الإخراج.2"},output_blocks_3:{name:"كتل الإخراج.3"},output_blocks_4:{name:"كتل الإخراج.4"},output_blocks_5:{name:"كتل الإخراج.5"},output_blocks_6:{name:"كتل الإخراج.6"},output_blocks_7:{name:"كتل الإخراج.7"},output_blocks_8:{name:"كتل الإخراج.8"},time_embed_:{name:"تضمين الوقت."}}},Wa={display_name:"دمج النموذج البسيط",inputs:{model1:{name:"النموذج 1"},model2:{name:"النموذج 2"},ratio:{name:"النسبة"}}},Ya={display_name:"طرح النموذج المدمج",inputs:{model1:{name:"النموذج 1"},model2:{name:"النموذج 2"},multiplier:{name:"المضاعف"}}},qa={description:"النموذج 1.3B يحتوي على 30 كتلة، النموذج 14B يحتوي على 40 كتلة. نموذج الصورة إلى الفيديو يحتوي على تضمين صورة إضافي.",display_name:"دمج النموذج WAN2_1",inputs:{blocks_0_:{name:"الكتل.0."},blocks_10_:{name:"الكتل.10."},blocks_11_:{name:"الكتل.11."},blocks_12_:{name:"الكتل.12."},blocks_13_:{name:"الكتل.13."},blocks_14_:{name:"الكتل.14."},blocks_15_:{name:"الكتل.15."},blocks_16_:{name:"الكتل.16."},blocks_17_:{name:"الكتل.17."},blocks_18_:{name:"الكتل.18."},blocks_19_:{name:"الكتل.19."},blocks_1_:{name:"الكتل.1."},blocks_20_:{name:"الكتل.20."},blocks_21_:{name:"الكتل.21."},blocks_22_:{name:"الكتل.22."},blocks_23_:{name:"الكتل.23."},blocks_24_:{name:"الكتل.24."},blocks_25_:{name:"الكتل.25."},blocks_26_:{name:"الكتل.26."},blocks_27_:{name:"الكتل.27."},blocks_28_:{name:"الكتل.28."},blocks_29_:{name:"الكتل.29."},blocks_2_:{name:"الكتل.2."},blocks_30_:{name:"الكتل.30."},blocks_31_:{name:"الكتل.31."},blocks_32_:{name:"الكتل.32."},blocks_33_:{name:"الكتل.33."},blocks_34_:{name:"الكتل.34."},blocks_35_:{name:"الكتل.35."},blocks_36_:{name:"الكتل.36."},blocks_37_:{name:"الكتل.37."},blocks_38_:{name:"الكتل.38."},blocks_39_:{name:"الكتل.39."},blocks_3_:{name:"الكتل.3."},blocks_4_:{name:"الكتل.4."},blocks_5_:{name:"الكتل.5."},blocks_6_:{name:"الكتل.6."},blocks_7_:{name:"الكتل.7."},blocks_8_:{name:"الكتل.8."},blocks_9_:{name:"الكتل.9."},head_:{name:"الرأس."},img_emb_:{name:"تضمين الصورة."},model1:{name:"النموذج 1"},model2:{name:"النموذج 2"},patch_embedding_:{name:"تضمين الرقعة."},text_embedding_:{name:"تضمين النص."},time_embedding_:{name:"تضمين الوقت."},time_projection_:{name:"إسقاط الوقت."}}},Za={display_name:"تدفق عينات النموذج AuraFlow",inputs:{model:{name:"النموذج"},shift:{name:"الإزاحة"}}},Qa={display_name:"تدفق عينات النموذج EDM المستمر",inputs:{model:{name:"النموذج"},sampling:{name:"العينة"},sigma_max:{name:"سيغما القصوى"},sigma_min:{name:"سيغما الدنيا"}}},Ja={display_name:"تدفق عينات النموذج V المستمر",inputs:{model:{name:"النموذج"},sampling:{name:"العينة"},sigma_max:{name:"سيغما القصوى"},sigma_min:{name:"سيغما الدنيا"}}},$a={display_name:"تدفق عينات النموذج المتقطع",inputs:{model:{name:"النموذج"},sampling:{name:"العينة"},zsnr:{name:"zsnr"}}},et={display_name:"تدفق عينات النموذج Flux",inputs:{base_shift:{name:"الإزاحة الأساسية"},height:{name:"الارتفاع"},max_shift:{name:"أقصى إزاحة"},model:{name:"النموذج"},width:{name:"العرض"}}},nt={display_name:"تدفق عينات النموذج LTXV",inputs:{base_shift:{name:"الإزاحة الأساسية"},latent:{name:"الكامن"},max_shift:{name:"أقصى إزاحة"},model:{name:"النموذج"}}},at={display_name:"تدفق عينات النموذج SD3",inputs:{model:{name:"النموذج"},shift:{name:"الإزاحة"}}},tt={display_name:"تدفق عينات النموذج StableCascade",inputs:{model:{name:"النموذج"},shift:{name:"الإزاحة"}}},ot={display_name:"حفظ النموذج",inputs:{filename_prefix:{name:"بادئة اسم الملف"},model:{name:"النموذج"}}},mt={display_name:"مورفولوجيا الصورة",inputs:{image:{name:"الصورة"},kernel_size:{name:"حجم النواة"},operation:{name:"العملية"}}},it={description:"ينشئ صورًا بشكل متزامن عبر نقطة نهاية DALL·E 2 من OpenAI.",display_name:"OpenAI DALL·E 2",inputs:{control_after_generate:{name:"التحكم بعد الإنشاء"},image:{name:"الصورة",tooltip:"صورة مرجعية اختيارية لتحرير الصور."},mask:{name:"القناع",tooltip:"قناع اختياري للرسم الداخلي (سيتم استبدال المناطق البيضاء)"},n:{name:"عدد الصور",tooltip:"كم عدد الصور التي يتم إنشاؤها"},prompt:{name:"النص الوصفي",tooltip:"النص الوصفي لـ DALL·E"},seed:{name:"البذرة",tooltip:"لم يتم تنفيذه بعد في الخلفية"},size:{name:"الحجم",tooltip:"حجم الصورة"}}},st={description:"ينشئ صورًا بشكل متزامن عبر نقطة نهاية DALL·E 3 من OpenAI.",display_name:"OpenAI DALL·E 3",inputs:{control_after_generate:{name:"التحكم بعد الإنشاء"},prompt:{name:"النص الوصفي",tooltip:"النص الوصفي لـ DALL·E"},quality:{name:"الجودة",tooltip:"جودة الصورة"},seed:{name:"البذرة",tooltip:"لم يتم تنفيذه بعد في الخلفية"},size:{name:"الحجم",tooltip:"حجم الصورة"},style:{name:"الأسلوب",tooltip:"النمط 'Vivid' يجعل النموذج يميل لإنشاء صور فائقة الواقعية ودرامية. النمط 'Natural' يجعل النموذج ينتج صورًا أكثر طبيعية وأقل واقعية بشكل مبالغ."}}},_t={description:"ينشئ صورًا بشكل متزامن عبر نقطة نهاية GPT Image 1 من OpenAI.",display_name:"OpenAI GPT صورة 1",inputs:{background:{name:"الخلفية",tooltip:"إرجاع الصورة مع أو بدون خلفية"},control_after_generate:{name:"التحكم بعد الإنشاء"},image:{name:"الصورة",tooltip:"صورة مرجعية اختيارية لتحرير الصور."},mask:{name:"القناع",tooltip:"قناع اختياري للرسم الداخلي (سيتم استبدال المناطق البيضاء)"},n:{name:"عدد الصور",tooltip:"كم عدد الصور التي يتم إنشاؤها"},prompt:{name:"النص الوصفي",tooltip:"النص الوصفي لـ GPT Image 1"},quality:{name:"الجودة",tooltip:"جودة الصورة، تؤثر على التكلفة ووقت الإنشاء."},seed:{name:"البذرة",tooltip:"لم يتم تنفيذه بعد في الخلفية"},size:{name:"الحجم",tooltip:"حجم الصورة"}}},lt={display_name:"مجدول الخطوات الأمثل",inputs:{denoise:{name:"إزالة الضجيج"},model_type:{name:"نوع النموذج"},steps:{name:"عدد الخطوات"}}},pt={display_name:"دمج زوج الشرط",inputs:{negative_A:{name:"سلبي A"},negative_B:{name:"سلبي B"},positive_A:{name:"إيجابي A"},positive_B:{name:"إيجابي B"}},outputs:{0:{name:"إيجابي"},1:{name:"سلبي"}}},ct={display_name:"تعيين الدمج الافتراضي لزوج الشرط",inputs:{hooks:{name:"خطافات"},negative:{name:"سلبي"},negative_DEFAULT:{name:"سلبي افتراضي"},positive:{name:"إيجابي"},positive_DEFAULT:{name:"إيجابي افتراضي"}},outputs:{0:{name:"إيجابي"},1:{name:"سلبي"}}},dt={display_name:"تعيين خصائص زوج الشرط",inputs:{hooks:{name:"خطافات"},mask:{name:"القناع"},negative_NEW:{name:"سلبي جديد"},positive_NEW:{name:"إيجابي جديد"},set_cond_area:{name:"تعيين منطقة الشرط"},strength:{name:"القوة"},timesteps:{name:"خطوات الزمن"}},outputs:{0:{name:"إيجابي"},1:{name:"سلبي"}}},rt={display_name:"تعيين ودمج خصائص زوج الشرط",inputs:{hooks:{name:"خطافات"},mask:{name:"القناع"},negative:{name:"سلبي"},negative_NEW:{name:"سلبي جديد"},positive:{name:"إيجابي"},positive_NEW:{name:"إيجابي جديد"},set_cond_area:{name:"تعيين منطقة الشرط"},strength:{name:"القوة"},timesteps:{name:"خطوات الزمن"}},outputs:{0:{name:"إيجابي"},1:{name:"سلبي"}}},ut={display_name:"إضافة تقليل الحجم للنموذج (Kohya Deep Shrink)",inputs:{block_number:{name:"رقم الكتلة"},downscale_after_skip:{name:"التصغير بعد التخطي"},downscale_factor:{name:"عامل التصغير"},downscale_method:{name:"طريقة التصغير"},end_percent:{name:"نسبة النهاية"},model:{name:"النموذج"},start_percent:{name:"نسبة البداية"},upscale_method:{name:"طريقة التكبير"}}},gt={display_name:"Perp-Neg (تم إهماله بواسطة PerpNegGuider)",inputs:{empty_conditioning:{name:"تهيئة فارغة"},model:{name:"النموذج"},neg_scale:{name:"مقياس سلبي"}}},bt={display_name:"PerpNegGuider",inputs:{cfg:{name:"إعدادات CFG"},empty_conditioning:{name:"تهيئة فارغة"},model:{name:"النموذج"},neg_scale:{name:"مقياس سلبي"},negative:{name:"سلبي"},positive:{name:"إيجابي"}}},yt={display_name:"توجيه الانتباه المتغير",inputs:{model:{name:"النموذج"},scale:{name:"المقياس"}}},kt={display_name:"ترميز صانع الصور",inputs:{clip:{name:"مقطع"},image:{name:"الصورة"},photomaker:{name:"صانع الصور"},text:{name:"النص"}}},ht={display_name:"محمل صانع الصور",inputs:{photomaker_model_name:{name:"اسم نموذج صانع الصور"}}},Lt={description:"يرسل صورة ونص وصف إلى واجهة برمجة تطبيقات بيك v2.2 لإنشاء فيديو.",display_name:"تحويل صورة إلى فيديو بيك",inputs:{control_after_generate:{name:"التحكم بعد الإنشاء"},duration:{name:"المدة"},image:{name:"الصورة",tooltip:"الصورة المراد تحويلها إلى فيديو"},negative_prompt:{name:"الوصف السلبي"},prompt_text:{name:"نص الوصف"},resolution:{name:"الدقة"},seed:{name:"البذرة"}}},Ct={description:"ادمج صورك لإنشاء فيديو يحتوي على الكائنات الموجودة فيها. قم برفع عدة صور كمكونات وأنشئ فيديو عالي الجودة يدمج جميعها.",display_name:"مشاهد بيك (تكوين فيديو من الصور)",inputs:{aspect_ratio:{name:"نسبة العرض إلى الارتفاع",tooltip:"نسبة العرض إلى الارتفاع (العرض / الارتفاع)"},control_after_generate:{name:"التحكم بعد الإنشاء"},duration:{name:"المدة"},image_ingredient_1:{name:"مكون الصورة 1",tooltip:"الصورة التي ستُستخدم كمكون لإنشاء الفيديو."},image_ingredient_2:{name:"مكون الصورة 2",tooltip:"الصورة التي ستُستخدم كمكون لإنشاء الفيديو."},image_ingredient_3:{name:"مكون الصورة 3",tooltip:"الصورة التي ستُستخدم كمكون لإنشاء الفيديو."},image_ingredient_4:{name:"مكون الصورة 4",tooltip:"الصورة التي ستُستخدم كمكون لإنشاء الفيديو."},image_ingredient_5:{name:"مكون الصورة 5",tooltip:"الصورة التي ستُستخدم كمكون لإنشاء الفيديو."},ingredients_mode:{name:"وضع المكونات"},negative_prompt:{name:"الوصف السلبي"},prompt_text:{name:"نص الوصف"},resolution:{name:"الدقة"},seed:{name:"البذرة"}}},St={description:"أنشئ فيديوً بدمج أول وآخر إطارين. قم برفع صورتين لتحديد نقاط البداية والنهاية، ودع الذكاء الاصطناعي ينشئ انتقالاً سلساً بينهما.",display_name:"إطارات بداية ونهاية بيك إلى فيديو",inputs:{control_after_generate:{name:"التحكم بعد الإنشاء"},duration:{name:"المدة"},image_end:{name:"صورة النهاية",tooltip:"الصورة الأخيرة للدمج."},image_start:{name:"صورة البداية",tooltip:"الصورة الأولى للدمج."},negative_prompt:{name:"الوصف السلبي"},prompt_text:{name:"نص الوصف"},resolution:{name:"الدقة"},seed:{name:"البذرة"}}},ft={description:"يرسل نص المطالبة إلى واجهة برمجة تطبيقات بيكا الإصدار 2.2 لتوليد فيديو.",display_name:"بيكا نص إلى فيديو",inputs:{aspect_ratio:{name:"نسبة العرض إلى الارتفاع",tooltip:"نسبة العرض إلى الارتفاع (العرض / الارتفاع)"},control_after_generate:{name:"التحكم بعد التوليد"},duration:{name:"المدة"},negative_prompt:{name:"نص المطالبة السلبية"},prompt_text:{name:"نص المطالبة"},resolution:{name:"الدقة"},seed:{name:"البذرة"}}},vt={description:"أضف أي كائن أو صورة إلى الفيديو الخاص بك. قم برفع فيديو وحدد ما تريد إضافته لإنشاء نتيجة مدمجة بسلاسة.",display_name:"إضافات بيك (إدخال كائن فيديو)",inputs:{control_after_generate:{name:"التحكم بعد الإنشاء"},image:{name:"الصورة",tooltip:"الصورة التي تريد إضافتها إلى الفيديو."},negative_prompt:{name:"الوصف السلبي"},prompt_text:{name:"نص الوصف"},seed:{name:"البذرة"},video:{name:"الفيديو",tooltip:"الفيديو الذي تريد إضافة صورة إليه."}}},It={description:"أنشئ فيديو مع تأثير بيك محدد. التأثيرات المدعومة: تزيين الكيك، التفتيت، السحق، القطع، الانكماش، الذوبان، الانفجار، بروز العين، النفخ، التعليق، الذوبان، التقشير، الوخز، السحق، تعبير المفاجأة، التمزق",display_name:"تأثيرات بيك (تأثيرات الفيديو)",inputs:{control_after_generate:{name:"التحكم بعد الإنشاء"},image:{name:"الصورة",tooltip:"الصورة المرجعية لتطبيق التأثير عليها."},negative_prompt:{name:"الوصف السلبي"},pikaffect:{name:"تأثير بيك"},prompt_text:{name:"نص الوصف"},seed:{name:"البذرة"}}},Pt={description:"استبدل أي كائن أو منطقة في الفيديو الخاص بك بصورة أو كائن جديد. عرّف المناطق التي تريد استبدالها إما بقناع أو بإحداثيات.",display_name:"بيكا سوابس (استبدال كائن الفيديو)",inputs:{control_after_generate:{name:"التحكم بعد التوليد"},image:{name:"الصورة",tooltip:"الصورة المستخدمة لاستبدال الكائن المقنع في الفيديو."},mask:{name:"القناع",tooltip:"استخدم القناع لتحديد المناطق التي سيتم استبدالها في الفيديو."},negative_prompt:{name:"نص المطالبة السلبية"},prompt_text:{name:"نص المطالبة"},seed:{name:"البذرة"},video:{name:"الفيديو",tooltip:"الفيديو الذي سيتم استبدال كائن فيه."}}},Mt={description:"ينتج فيديوهات بشكل متزامن بناءً على النص المطلوب وحجم المخرج.",display_name:"بيكسفيرس صورة إلى فيديو",inputs:{control_after_generate:{name:"التحكم بعد التوليد"},duration_seconds:{name:"مدة الثواني"},image:{name:"الصورة"},motion_mode:{name:"وضع الحركة"},negative_prompt:{name:"نص المطالبة السلبية",tooltip:"وصف نصي اختياري للعناصر غير المرغوبة في الصورة."},pixverse_template:{name:"قالب بيكسفيرس",tooltip:"قالب اختياري للتأثير على نمط التوليد، يتم إنشاؤه بواسطة عقدة قالب بيكسفيرس."},prompt:{name:"النص المطلوب",tooltip:"النص المطلوب لتوليد الفيديو"},quality:{name:"الجودة"},seed:{name:"البذرة",tooltip:"البذرة لتوليد الفيديو."}}},At={display_name:"قالب بيكسفيرس",inputs:{template:{name:"القالب"}},outputs:{0:{name:"قالب بيكسفيرس"}}},Vt={description:"ينتج فيديوهات بشكل متزامن بناءً على النص المطلوب وحجم المخرج.",display_name:"بيكسفيرس نص إلى فيديو",inputs:{aspect_ratio:{name:"نسبة العرض إلى الارتفاع"},control_after_generate:{name:"التحكم بعد التوليد"},duration_seconds:{name:"مدة الثواني"},motion_mode:{name:"وضع الحركة"},negative_prompt:{name:"نص المطالبة السلبية",tooltip:"وصف نصي اختياري للعناصر غير المرغوبة في الصورة."},pixverse_template:{name:"قالب بيكسفيرس",tooltip:"قالب اختياري للتأثير على نمط التوليد، يتم إنشاؤه بواسطة عقدة قالب بيكسفيرس."},prompt:{name:"النص المطلوب",tooltip:"النص المطلوب لتوليد الفيديو"},quality:{name:"الجودة"},seed:{name:"البذرة",tooltip:"البذرة لتوليد الفيديو."}}},xt={description:"ينتج فيديوهات بشكل متزامن بناءً على النص المطلوب وحجم المخرج.",display_name:"بيكسفيرس فيديو الانتقال",inputs:{control_after_generate:{name:"التحكم بعد التوليد"},duration_seconds:{name:"مدة الثواني"},first_frame:{name:"الإطار الأول"},last_frame:{name:"الإطار الأخير"},motion_mode:{name:"وضع الحركة"},negative_prompt:{name:"نص المطالبة السلبية",tooltip:"وصف نصي اختياري للعناصر غير المرغوبة في الصورة."},prompt:{name:"النص المطلوب",tooltip:"النص المطلوب لتوليد الفيديو"},quality:{name:"الجودة"},seed:{name:"البذرة",tooltip:"البذرة لتوليد الفيديو."}}},Tt={display_name:"جدولة متعددة الأسية",inputs:{rho:{name:"رو"},sigma_max:{name:"سيغما ماكس"},sigma_min:{name:"سيغما مين"},steps:{name:"الخطوات"}}},Et={display_name:"تركيب صورة بورتر-داف",inputs:{destination:{name:"الوجهة"},destination_alpha:{name:"ألفا الوجهة"},mode:{name:"الوضع"},source:{name:"المصدر"},source_alpha:{name:"ألفا المصدر"}}},Dt={display_name:"معاينة ثلاثية الأبعاد",inputs:{camera_info:{name:"معلومات الكاميرا"},image:{name:"الصورة"},model_file:{name:"ملف النموذج"}}},Nt={display_name:"معاينة ثلاثية الأبعاد - حركة",inputs:{camera_info:{name:"معلومات الكاميرا"},model_file:{name:"ملف النموذج"}}},Gt={display_name:"معاينة أي",inputs:{preview:{},source:{name:"المصدر"}}},Ft={display_name:"معاينة الصوت",inputs:{audio:{name:"الصوت"},audioUI:{name:"واجهة المستخدم للصوت"}}},Rt={description:"يحفظ الصور المدخلة في دليل مخرجات ComfyUI الخاص بك.",display_name:"معاينة الصورة",inputs:{images:{name:"الصور"}}},Bt={display_name:"منطقي",inputs:{value:{name:"القيمة"}}},wt={display_name:"عائم",inputs:{value:{name:"القيمة"}}},Ut={display_name:"عدد صحيح",inputs:{control_after_generate:{name:"التحكم بعد التوليد"},value:{name:"القيمة"}}},jt={display_name:"نص",inputs:{value:{name:"القيمة"}}},Ht={display_name:"نص (متعدد الأسطر)",inputs:{value:{name:"القيمة"}}},Xt={description:`[وصفات]

hidream: long clip-l, long clip-g, t5xxl, llama_8b_3.1_instruct`,display_name:"محمل CLIP رباعي",inputs:{clip_name1:{name:"اسم الكليب 1"},clip_name2:{name:"اسم الكليب 2"},clip_name3:{name:"اسم الكليب 3"},clip_name4:{name:"اسم الكليب 4"}}},zt={display_name:"ضجيج عشوائية",inputs:{control_after_generate:{name:"التحكم بعد التوليد"},noise_seed:{name:"بذرة الضجيج"}}},Kt={display_name:"إعادة تجميع الصور",inputs:{batch_size:{name:"حجم الدفعة"},images:{name:"الصور"}}},Ot={display_name:"إعادة تجميع المتغيرات الكامنة",inputs:{batch_size:{name:"حجم الدفعة"},latents:{name:"المتغيرات الكامنة"}}},Wt={description:"إنشاء لون Recraft باختيار قيم RGB محددة.",display_name:"إعادة صياغة لون RGB",inputs:{b:{name:"الأزرق",tooltip:"قيمة اللون الأزرق."},g:{name:"الأخضر",tooltip:"قيمة اللون الأخضر."},r:{name:"الأحمر",tooltip:"قيمة اللون الأحمر."},recraft_color:{name:"لون إعادة الصياغة"}},outputs:{0:{name:"لون إعادة الصياغة"}}},Yt={description:"إنشاء عناصر تحكم Recraft لتخصيص توليد Recraft.",display_name:"عناصر تحكم إعادة الصياغة",inputs:{background_color:{name:"لون الخلفية"},colors:{name:"الألوان"}},outputs:{0:{name:"عناصر تحكم إعادة الصياغة"}}},qt={description:`تكبير الصورة بشكل متزامن.
يعزز صورة نقطية معينة باستخدام أداة 'التكبير الإبداعي'، مع التركيز على تحسين التفاصيل الصغيرة والوجوه.`,display_name:"تكبير إبداعي لإعادة الصياغة",inputs:{image:{name:"الصورة"}}},Zt={description:`تكبير الصورة بشكل متزامن.
يعزز صورة نقطية معينة باستخدام أداة 'تكبير الوضوح'، مما يزيد دقة الصورة ويجعلها أكثر حدة ونقاء.`,display_name:"إعادة صياغة صورة عالية الوضوح",inputs:{image:{name:"صورة"}}},Qt={description:"تعديل الصورة بناءً على الوصف والقناع.",display_name:"إعادة صياغة ترميم الصورة",inputs:{control_after_generate:{name:"التحكم بعد الإنشاء"},image:{name:"صورة"},mask:{name:"قناع"},n:{name:"عدد",tooltip:"عدد الصور المراد إنشاؤها."},negative_prompt:{name:"الوصف السلبي",tooltip:"وصف نصي اختياري للعناصر غير المرغوبة في الصورة."},prompt:{name:"الوصف",tooltip:"الوصف المستخدم لإنشاء الصورة."},recraft_style:{name:"نمط إعادة الصياغة"},seed:{name:"بذرة",tooltip:"بذرة لتحديد ما إذا كان يجب إعادة تشغيل العقدة؛ النتائج الفعلية غير حتمية بغض النظر عن البذرة."}}},Jt={description:"تعديل الصورة بناءً على الوصف والقوة.",display_name:"إعادة صياغة صورة إلى صورة",inputs:{control_after_generate:{name:"التحكم بعد الإنشاء"},image:{name:"صورة"},n:{name:"عدد",tooltip:"عدد الصور المراد إنشاؤها."},negative_prompt:{name:"الوصف السلبي",tooltip:"وصف نصي اختياري للعناصر غير المرغوبة في الصورة."},prompt:{name:"الوصف",tooltip:"الوصف المستخدم لإنشاء الصورة."},recraft_controls:{name:"عناصر تحكم إعادة الصياغة",tooltip:"عناصر تحكم إضافية اختيارية عبر عقدة عناصر تحكم إعادة الصياغة."},recraft_style:{name:"نمط إعادة الصياغة"},seed:{name:"بذرة",tooltip:"بذرة لتحديد ما إذا كان يجب إعادة تشغيل العقدة؛ النتائج الفعلية غير حتمية بغض النظر عن البذرة."},strength:{name:"القوة",tooltip:"تعريف الاختلاف عن الصورة الأصلية، يجب أن يكون في النطاق [0, 1]، حيث 0 يعني شبه مطابق، و1 يعني اختلاف كبير."}}},$t={description:"إزالة الخلفية من الصورة، وإرجاع الصورة المعالجة والقناع.",display_name:"إعادة صياغة إزالة الخلفية",inputs:{image:{name:"صورة"}}},eo={description:"استبدال الخلفية في الصورة بناءً على الوصف المقدم.",display_name:"إعادة صياغة استبدال الخلفية",inputs:{control_after_generate:{name:"التحكم بعد الإنشاء"},image:{name:"صورة"},n:{name:"عدد",tooltip:"عدد الصور المراد إنشاؤها."},negative_prompt:{name:"الوصف السلبي",tooltip:"وصف نصي اختياري للعناصر غير المرغوبة في الصورة."},prompt:{name:"الوصف",tooltip:"الوصف المستخدم لإنشاء الصورة."},recraft_style:{name:"نمط إعادة الصياغة"},seed:{name:"بذرة",tooltip:"بذرة لتحديد ما إذا كان يجب إعادة تشغيل العقدة؛ النتائج الفعلية غير حتمية بغض النظر عن البذرة."}}},no={description:"اختر نمط الصورة الواقعية والنمط الفرعي الاختياري.",display_name:"نمط إعادة الصياغة - الرسم الرقمي",inputs:{substyle:{name:"النمط الفرعي"}},outputs:{0:{name:"نمط إعادة الصياغة"}}},ao={description:"اختر نمطاً بناءً على UUID موجود مسبقًا من مكتبة أنماط إعادة الصياغة اللانهائية.",display_name:"نمط إعادة الصياغة - مكتبة الأنماط اللانهائية",inputs:{style_id:{name:"معرف النمط",tooltip:"UUID للنمط من مكتبة الأنماط اللانهائية."}},outputs:{0:{name:"نمط إعادة الصياغة"}}},to={description:"اختر نمط الصورة الواقعية والنمط الفرعي الاختياري.",display_name:"نمط إعادة الصياغة - شعار نقطي",inputs:{substyle:{name:"النمط الفرعي"}},outputs:{0:{name:"نمط إعادة الصياغة"}}},oo={description:"اختر نمط الصورة الواقعية والنمط الفرعي الاختياري.",display_name:"نمط إعادة الصياغة - صورة واقعية",inputs:{substyle:{name:"النمط الفرعي"}},outputs:{0:{name:"نمط إعادة الصياغة"}}},mo={description:"ينشئ صورًا بشكل متزامن بناءً على الوصف والدقة.",display_name:"إعادة صياغة نص إلى صورة",inputs:{control_after_generate:{name:"التحكم بعد الإنشاء"},n:{name:"عدد",tooltip:"عدد الصور المراد إنشاؤها."},negative_prompt:{name:"الوصف السلبي",tooltip:"وصف نصي اختياري للعناصر غير المرغوبة في الصورة."},prompt:{name:"الوصف",tooltip:"الوصف المستخدم لإنشاء الصورة."},recraft_controls:{name:"عناصر تحكم إعادة الصياغة",tooltip:"عناصر تحكم إضافية اختيارية عبر عقدة عناصر تحكم إعادة الصياغة."},recraft_style:{name:"نمط إعادة الصياغة"},seed:{name:"بذرة",tooltip:"بذرة لتحديد ما إذا كان يجب إعادة تشغيل العقدة؛ النتائج الفعلية غير حتمية بغض النظر عن البذرة."},size:{name:"الحجم",tooltip:"حجم الصورة المُنشأة."}}},io={description:"ينشئ SVG بشكل متزامن بناءً على الوصف والدقة.",display_name:"إعادة صياغة نص إلى متجه",inputs:{control_after_generate:{name:"التحكم بعد الإنشاء"},n:{name:"عدد",tooltip:"عدد الصور المراد إنشاؤها."},negative_prompt:{name:"الوصف السلبي",tooltip:"وصف نصي اختياري للعناصر غير المرغوبة في الصورة."},prompt:{name:"الوصف",tooltip:"الوصف المستخدم لإنشاء الصورة."},recraft_controls:{name:"عناصر تحكم إعادة الصياغة",tooltip:"عناصر تحكم إضافية اختيارية عبر عقدة عناصر تحكم إعادة الصياغة."},seed:{name:"بذرة",tooltip:"بذرة لتحديد ما إذا كان يجب إعادة تشغيل العقدة؛ النتائج الفعلية غير حتمية بغض النظر عن البذرة."},size:{name:"الحجم",tooltip:"حجم الصورة المُنشأة."},substyle:{name:"النمط الفرعي"}}},so={description:"ينشئ SVG بشكل متزامن من صورة إدخال.",display_name:"إعادة صياغة تحويل الصورة إلى متجه",inputs:{image:{name:"صورة"}}},_o={display_name:"إعادة تهيئة CFG",inputs:{cfg_trunc:{name:"اقتطاع CFG"},model:{name:"النموذج"},renorm_cfg:{name:"إعادة تهيئة CFG"}}},lo={display_name:"تكرار دفعة الصور",inputs:{amount:{name:"الكمية"},image:{name:"الصورة"}}},po={display_name:"تكرار دفعة الخفاء",inputs:{amount:{name:"الكمية"},samples:{name:"عينات"}}},co={display_name:"إعادة تحجيم CFG",inputs:{model:{name:"النموذج"},multiplier:{name:"المُضَاعِف"}}},ro={display_name:"جدول SD Turbo",inputs:{denoise:{name:"إزالة التشويش"},model:{name:"النموذج"},steps:{name:"الخطوات"}}},uo={display_name:"تحسين SD 4X",inputs:{images:{name:"الصور"},negative:{name:"سلبي"},noise_augmentation:{name:"تعزيز الضجيج"},positive:{name:"إيجابي"},scale_ratio:{name:"نسبة المقياس"}},outputs:{0:{name:"إيجابي"},1:{name:"سلبي"},2:{name:"كامن"}}},go={display_name:"تهيئة SV3D",inputs:{clip_vision:{name:"رؤية المقطع"},elevation:{name:"الارتفاع الزاوي"},height:{name:"الارتفاع"},init_image:{name:"الصورة الأصلية"},vae:{name:"vae"},video_frames:{name:"إطارات الفيديو"},width:{name:"العرض"}},outputs:{0:{name:"إيجابي"},1:{name:"سلبي"},2:{name:"كامِن"}}},bo={display_name:"تهيئة تحويل صورة إلى فيديو من SVD",inputs:{augmentation_level:{name:"مستوى التضخيم"},clip_vision:{name:"رؤية المقطع"},fps:{name:"الإطارات في الثانية"},height:{name:"الارتفاع"},init_image:{name:"الصورة الأصلية"},motion_bucket_id:{name:"معرف دلو الحركة"},vae:{name:"vae"},video_frames:{name:"إطارات الفيديو"},width:{name:"العرض"}},outputs:{0:{name:"إيجابي"},1:{name:"سلبي"},2:{name:"كامِن"}}},yo={display_name:"المُعين المخصص",inputs:{add_noise:{name:"إضافة ضجيج"},cfg:{name:"CFG"},control_after_generate:{name:"التحكم بعد التوليد"},latent_image:{name:"صورة الخفاء"},model:{name:"النموذج"},negative:{name:"السلبي"},noise_seed:{name:"بذرة الضجيج"},positive:{name:"الإيجابي"},sampler:{name:"المُعين"},sigmas:{name:"سيغما"}},outputs:{0:{name:"المخرج"},1:{name:"المخرج المنقح"}}},ko={display_name:"المُعين المخصص المتقدم",inputs:{guider:{name:"الدليل"},latent_image:{name:"صورة الخفاء"},noise:{name:"الضجيج"},sampler:{name:"المُعين"},sigmas:{name:"سيغما"}},outputs:{0:{name:"المخرج"},1:{name:"المخرج المنقح"}}},ho={display_name:"المُعين DPM التكيفي",inputs:{accept_safety:{name:"قبول الأمان"},atol:{name:"atol"},dcoeff:{name:"dcoeff"},eta:{name:"إيتا"},h_init:{name:"h_init"},icoeff:{name:"icoeff"},order:{name:"الترتيب"},pcoeff:{name:"pcoeff"},rtol:{name:"rtol"},s_noise:{name:"ضجيج s"}}},Lo={display_name:"المُعين DPMPP_2M_SDE",inputs:{eta:{name:"إيتا"},noise_device:{name:"جهاز الضجيج"},s_noise:{name:"ضجيج s"},solver_type:{name:"نوع المُحلل"}}},Co={display_name:"المُعين DPMPP_2S_Ancestral",inputs:{eta:{name:"إيتا"},s_noise:{name:"ضجيج s"}}},So={display_name:"المُعين DPMPP_3M_SDE",inputs:{eta:{name:"إيتا"},noise_device:{name:"جهاز الضجيج"},s_noise:{name:"ضجيج s"}}},fo={display_name:"المُعين DPMPP_SDE",inputs:{eta:{name:"إيتا"},noise_device:{name:"جهاز الضجيج"},r:{name:"r"},s_noise:{name:"ضجيج s"}}},vo={display_name:"المُعين Euler الأثري",inputs:{eta:{name:"إيتا"},s_noise:{name:"ضجيج s"}}},Io={display_name:"المُعين Euler الأثري CFG++",inputs:{eta:{name:"إيتا"},s_noise:{name:"ضجيج s"}}},Po={display_name:"المُعين Euler CFG++",inputs:{version:{name:"الإصدار"}}},Mo={display_name:"المُعين LCM للتكبير",inputs:{scale_ratio:{name:"نسبة التكبير"},scale_steps:{name:"خطوات التكبير"},upscale_method:{name:"طريقة التكبير"}}},Ao={display_name:"المُعين LMS",inputs:{order:{name:"الترتيب"}}},Vo={display_name:"حفظ PNG متحرك",inputs:{compress_level:{name:"مستوى الضغط"},filename_prefix:{name:"بادئة اسم الملف"},fps:{name:"معدل الإطارات في الثانية"},images:{name:"الصور"}}},xo={display_name:"حفظ WEBP متحرك",inputs:{filename_prefix:{name:"بادئة اسم الملف"},fps:{name:"معدل الإطارات في الثانية"},images:{name:"الصور"},lossless:{name:"بدون خسارة"},method:{name:"الطريقة"},quality:{name:"الجودة"}}},To={display_name:"حفظ الصوت",inputs:{audio:{name:"الصوت"},audioUI:{name:"واجهة الصوت"},filename_prefix:{name:"بادئة اسم الملف"}}},Eo={display_name:"حفظ GLB",inputs:{filename_prefix:{name:"بادئة اسم الملف"},image:{name:"الصورة"},mesh:{name:"الشبكة"}}},Do={description:"يحفظ الصور المدخلة في مجلد مخرجات ComfyUI الخاص بك.",display_name:"حفظ الصورة",inputs:{filename_prefix:{name:"بادئة اسم الملف",tooltip:"بادئة اسم الملف للحفظ. يمكن أن تتضمن معلومات تنسيق مثل %date:yyyy-MM-dd% أو %Empty Latent Image.width% لاستخدام قيم من العقد."},images:{name:"الصور",tooltip:"الصور التي سيتم حفظها."}}},No={display_name:"حفظ صورة عبر Websocket",inputs:{images:{name:"الصور"}}},Go={display_name:"حفظ الكامن",inputs:{filename_prefix:{name:"بادئة اسم الملف"},samples:{name:"عينات"}}},Fo={description:"يحفظ الصور المدخلة في مجلد مخرجات ComfyUI الخاص بك.",display_name:"حفظ الفيديو",inputs:{codec:{name:"الترميز",tooltip:"الترميز المستخدم للفيديو."},filename_prefix:{name:"بادئة اسم الملف",tooltip:"بادئة اسم الملف للحفظ. يمكن أن تتضمن معلومات تنسيق مثل %date:yyyy-MM-dd% أو %Empty Latent Image.width% لاستخدام قيم من العقد."},format:{name:"الصيغة",tooltip:"الصيغة التي سيتم حفظ الفيديو بها."},video:{name:"الفيديو",tooltip:"الفيديو الذي سيتم حفظه."}}},Ro={display_name:"حفظ WEBM",inputs:{codec:{name:"الترميز"},crf:{name:"crf",tooltip:"كلما زاد crf انخفضت الجودة وحجم الملف، وكلما انخفض زادت الجودة وحجم الملف."},filename_prefix:{name:"بادئة اسم الملف"},fps:{name:"معدل الإطارات في الثانية"},images:{name:"الصور"}}},Bo={display_name:"توجيه الانتباه الذاتي",inputs:{blur_sigma:{name:"تمويه سيغما"},model:{name:"النموذج"},scale:{name:"المقياس"}}},wo={display_name:"تعيين CLIP Hooks",inputs:{apply_to_conds:{name:"تطبيق على الشروط"},clip:{name:"CLIP"},hooks:{name:"Hooks"},schedule_clip:{name:"جدولة CLIP"}}},Uo={display_name:"تعيين Sigma الأول",inputs:{sigma:{name:"Sigma"},sigmas:{name:"Sigmas"}}},jo={display_name:"تعيين إطارات مفتاحية للـ Hook",inputs:{hook_kf:{name:"الإطار المفتاحي للـ Hook"},hooks:{name:"Hooks"}}},Ho={display_name:"تعيين قناع ضجيج الكامن",inputs:{mask:{name:"القناع"},samples:{name:"عينات"}}},Xo={display_name:"تعيين نوع Union ControlNet",inputs:{control_net:{name:"شبكة التحكم"},type:{name:"النوع"}}},zo={description:"نسخة عامة من عقدة SkipLayerGuidance يمكن استخدامها مع كل نموذج DiT.",display_name:"توجيه تخطي الطبقة DiT",inputs:{double_layers:{name:"طبقات مزدوجة"},end_percent:{name:"نسبة النهاية"},model:{name:"النموذج"},rescaling_scale:{name:"مقياس إعادة التحجيم"},scale:{name:"المقياس"},single_layers:{name:"طبقات مفردة"},start_percent:{name:"نسبة البداية"}}},Ko={description:"نسخة عامة من عقدة SkipLayerGuidance يمكن استخدامها مع كل نموذج DiT.",display_name:"توجيه تخطي الطبقة SD3",inputs:{end_percent:{name:"نسبة النهاية"},layers:{name:"الطبقات"},model:{name:"النموذج"},scale:{name:"المقياس"},start_percent:{name:"نسبة البداية"}}},Oo={display_name:"قناع صلب",inputs:{height:{name:"الارتفاع"},value:{name:"القيمة"},width:{name:"العرض"}}},Wo={display_name:"فصل الصورة مع ألفا",inputs:{image:{name:"الصورة"}}},Yo={display_name:"فصل Sigmas",inputs:{sigmas:{name:"Sigmas"},step:{name:"الخطوة"}},outputs:{0:{name:"Sigmas عالية"},1:{name:"Sigmas منخفضة"}}},qo={display_name:"فصل Sigmas إزالة التشويش",inputs:{denoise:{name:"إزالة التشويش"},sigmas:{name:"Sigmas"}},outputs:{0:{name:"Sigmas عالية"},1:{name:"Sigmas منخفضة"}}},Zo={description:"ينتج الصور بشكل متزامن بناءً على النص والنسبة.",display_name:"Stability AI صورة Stable Diffusion 3.5",inputs:{aspect_ratio:{name:"نسبة العرض إلى الارتفاع",tooltip:"نسبة عرض الصورة الناتجة."},cfg_scale:{name:"مقياس CFG",tooltip:"مدى التزام عملية الانتشار بالنص الوصفي (القيم الأعلى تبقي الصورة أقرب للنص)."},control_after_generate:{name:"التحكم بعد الإنشاء"},image:{name:"الصورة"},image_denoise:{name:"إزالة التشويش من الصورة",tooltip:"0.0 تعني صورة مطابقة للأصل، 1.0 تعني عدم وجود صورة أصلية."},model:{name:"النموذج"},negative_prompt:{name:"نص سلبي",tooltip:"الكلمات التي لا ترغب برؤيتها في الصورة الناتجة. ميزة متقدمة."},prompt:{name:"النص الوصفي",tooltip:"ما ترغب برؤيته في الصورة الناتجة. نص وصفي قوي وواضح يحدد العناصر والألوان والموضوعات يؤدي لنتائج أفضل."},seed:{name:"البذرة",tooltip:"البذرة العشوائية لإنشاء الضجيج."},style_preset:{name:"نمط مسبق",tooltip:"النمط المرغوب اختياريًا للصورة الناتجة."}}},Qo={description:"ينتج الصور بشكل متزامن بناءً على النص والنسبة.",display_name:"Stability AI صورة Stable Ultra",inputs:{aspect_ratio:{name:"نسبة العرض إلى الارتفاع",tooltip:"نسبة عرض الصورة الناتجة."},control_after_generate:{name:"التحكم بعد الإنشاء"},image:{name:"الصورة"},image_denoise:{name:"إزالة التشويش من الصورة",tooltip:"0.0 تعني صورة مطابقة للأصل، 1.0 تعني عدم وجود صورة أصلية."},negative_prompt:{name:"نص سلبي",tooltip:"وصف لما لا ترغب برؤيته في الصورة الناتجة. ميزة متقدمة."},prompt:{name:"النص الوصفي",tooltip:"ما ترغب برؤيته في الصورة الناتجة. نص وصفي قوي وواضح يحدد العناصر والألوان والموضوعات يؤدي لنتائج أفضل. للتحكم في وزن كلمة معينة استخدم التنسيق (الكلمة:الوزن) حيث الوزن بين 0 و1."},seed:{name:"البذرة",tooltip:"البذرة العشوائية لإنشاء الضجيج."},style_preset:{name:"نمط مسبق",tooltip:"النمط المرغوب اختياريًا للصورة الناتجة."}}},Jo={description:"يكبر الصورة مع تغييرات طفيفة إلى دقة 4K.",display_name:"Stability AI تكبير محافظ",inputs:{control_after_generate:{name:"التحكم بعد الإنشاء"},creativity:{name:"الإبداع",tooltip:"يتحكم في احتمالية إضافة تفاصيل إضافية ليست متأثرة بقوة بالصورة الأصلية."},image:{name:"الصورة"},negative_prompt:{name:"نص سلبي",tooltip:"الكلمات التي لا ترغب برؤيتها في الصورة الناتجة. ميزة متقدمة."},prompt:{name:"النص الوصفي",tooltip:"ما ترغب برؤيته في الصورة الناتجة. نص وصفي قوي وواضح يحدد العناصر والألوان والموضوعات يؤدي لنتائج أفضل."},seed:{name:"البذرة",tooltip:"البذرة العشوائية لإنشاء الضجيج."}}},$o={description:"تكبير الصورة مع تغييرات طفيفة إلى دقة 4K.",display_name:"تكبير استقرار الذكاء الاصطناعي الإبداعي",inputs:{control_after_generate:{name:"التحكم بعد الإنشاء"},creativity:{name:"الإبداع",tooltip:"يتحكم في احتمالية إنشاء تفاصيل إضافية غير معتمدة بشكل كبير على الصورة الأصلية."},image:{name:"صورة"},negative_prompt:{name:"النص السلبي",tooltip:"كلمات مفتاحية لما لا ترغب في رؤيته في الصورة الناتجة. هذه ميزة متقدمة."},prompt:{name:"النص الوصفي",tooltip:"ما ترغب في رؤيته في الصورة الناتجة. النص الوصفي القوي والواضح الذي يحدد العناصر والألوان والمواضيع بدقة يؤدي إلى نتائج أفضل."},seed:{name:"البذرة",tooltip:"البذرة العشوائية المستخدمة لإنشاء الضجيج."},style_preset:{name:"نمط مسبق",tooltip:"النمط المرغوب اختياريًا للصورة المولدة."}}},em={description:"يزيد حجم الصورة بسرعة عبر استدعاء API الخاص باستقرار الذكاء الاصطناعي إلى 4 أضعاف الحجم الأصلي؛ مخصص لتكبير الصور منخفضة الجودة أو المضغوطة.",display_name:"تكبير استقرار الذكاء الاصطناعي السريع",inputs:{image:{name:"صورة"}}},nm={display_name:"صورة كامنة فارغة من StableCascade",inputs:{batch_size:{name:"حجم الدفعة"},compression:{name:"ضغط"},height:{name:"الارتفاع"},width:{name:"العرض"}},outputs:{0:{name:"المرحلة_ج"},1:{name:"المرحلة_ب"}}},am={display_name:"تهيئة المرحلة ب من StableCascade",inputs:{conditioning:{name:"تهيئة"},stage_c:{name:"المرحلة_ج"}}},tm={display_name:"ترميز VAE للمرحلة ج من StableCascade",inputs:{compression:{name:"ضغط"},image:{name:"صورة"},vae:{name:"vae"}},outputs:{0:{name:"المرحلة_ج"},1:{name:"المرحلة_ب"}}},om={display_name:"شبكة التحكم للدقة الفائقة من StableCascade",inputs:{image:{name:"صورة"},vae:{name:"vae"}},outputs:{0:{name:"مدخلات شبكة التحكم"},1:{name:"المرحلة_ج"},2:{name:"المرحلة_ب"}}},mm={display_name:"تهيئة StableZero123",inputs:{azimuth:{name:"السمت"},batch_size:{name:"حجم الدفعة"},clip_vision:{name:"رؤية المقطع"},elevation:{name:"الارتفاع الزاوي"},height:{name:"الارتفاع"},init_image:{name:"الصورة الأصلية"},vae:{name:"vae"},width:{name:"العرض"}},outputs:{0:{name:"إيجابي"},1:{name:"سلبي"},2:{name:"كامِن"}}},im={display_name:"تهيئة StableZero123 مجمعة",inputs:{azimuth:{name:"السمت"},azimuth_batch_increment:{name:"زيادة دفعة السمت"},batch_size:{name:"حجم الدفعة"},clip_vision:{name:"رؤية المقطع"},elevation:{name:"الارتفاع الزاوي"},elevation_batch_increment:{name:"زيادة دفعة الارتفاع الزاوي"},height:{name:"الارتفاع"},init_image:{name:"الصورة الأصلية"},vae:{name:"vae"},width:{name:"العرض"}},outputs:{0:{name:"إيجابي"},1:{name:"سلبي"},2:{name:"كامِن"}}},sm={display_name:"تطبيق نموذج النمط",inputs:{clip_vision_output:{name:"خرج رؤية المقطع"},conditioning:{name:"تهيئة"},strength:{name:"القوة"},strength_type:{name:"نوع القوة"},style_model:{name:"نموذج النمط"}}},_m={display_name:"تحميل نموذج النمط",inputs:{style_model_name:{name:"اسم نموذج النمط"}}},lm={display_name:"خيارات محلل T5",inputs:{clip:{name:"كليب"},min_length:{name:"الحد الأدنى للطول"},min_padding:{name:"الحد الأدنى للحشو"}}},pm={display_name:"ترميز النص لفيديو Hunyuan - من صورة إلى فيديو",inputs:{clip:{name:"كليب"},clip_vision_output:{name:"ناتج رؤية الكليب"},image_interleave:{name:"تداخل الصورة",tooltip:"مدى تأثير الصورة مقارنة بالموجه النصي. الرقم الأعلى يعني تأثير أكبر من الموجه النصي."},prompt:{name:"الموجه"}}},cm={display_name:"قناع العتبة",inputs:{mask:{name:"القناع"},value:{name:"القيمة"}}},dm={display_name:"نموذج TomePatch",inputs:{model:{name:"النموذج"},ratio:{name:"النسبة"}}},rm={display_name:"نموذج TorchCompile",inputs:{backend:{name:"الخلفية"},model:{name:"النموذج"}}},um={display_name:"اقتطاع فيديو الخفاء",inputs:{samples:{name:"العيّنات"},trim_amount:{name:"مقدار الاقتطاع"}}},gm={description:`[الوصفات]

sd3: clip-l, clip-g, t5`,display_name:"محمل TripleCLIP",inputs:{clip_name1:{name:"اسم الكليب 1"},clip_name2:{name:"اسم الكليب 2"},clip_name3:{name:"اسم الكليب 3"}}},bm={display_name:"تحميل نموذج الانتشار",inputs:{unet_name:{name:"اسم UNet"},weight_dtype:{name:"نوع بيانات الوزن"}}},ym={display_name:"ضرب انتباه التداخل لـ UNet",inputs:{k:{name:"k"},model:{name:"النموذج"},out:{name:"الناتج"},q:{name:"q"},v:{name:"v"}}},km={display_name:"ضرب انتباه الذات لـ UNet",inputs:{k:{name:"k"},model:{name:"النموذج"},out:{name:"الناتج"},q:{name:"q"},v:{name:"v"}}},hm={display_name:"ضرب الانتباه الزمني لـ UNet",inputs:{cross_structural:{name:"التركيب المتقاطع"},cross_temporal:{name:"الزمن المتقاطع"},model:{name:"النموذج"},self_structural:{name:"التركيب الذاتي"},self_temporal:{name:"الزمن الذاتي"}}},Lm={display_name:"تحميل نموذج التكبير",inputs:{model_name:{name:"اسم النموذج"}}},Cm={description:"يقوم بفك ترميز الصور الكامنة إلى صور في فضاء البكسل.",display_name:"فك ترميز VAE",inputs:{samples:{name:"عينات",tooltip:"الكامن المراد فك ترميزه."},vae:{name:"vae",tooltip:"نموذج VAE المستخدم لفك ترميز الكامن."}},outputs:{0:{tooltip:"الصورة المفكوكة الترميز."}}},Sm={display_name:"فك ترميز VAE للصوت",inputs:{samples:{name:"عينات"},vae:{name:"vae"}}},fm={display_name:"فك ترميز VAE Hunyuan3D",inputs:{num_chunks:{name:"عدد القطع"},octree_resolution:{name:"دقة شجرة الثماني"},samples:{name:"عينات"},vae:{name:"vae"}}},vm={display_name:"فك ترميز VAE (مبسط)",inputs:{overlap:{name:"التداخل"},samples:{name:"عينات"},temporal_overlap:{name:"التداخل الزمني",tooltip:"يستخدم فقط لـ VAEs الفيديو: عدد الإطارات المتداخلة."},temporal_size:{name:"الحجم الزمني",tooltip:"يستخدم فقط لـ VAEs الفيديو: عدد الإطارات التي يتم فك ترميزها في مرة واحدة."},tile_size:{name:"حجم القطعة"},vae:{name:"vae"}}},Im={display_name:"ترميز VAE",inputs:{pixels:{name:"بكسلات"},vae:{name:"vae"}}},Pm={display_name:"ترميز VAE للصوت",inputs:{audio:{name:"صوت"},vae:{name:"vae"}}},Mm={display_name:"ترميز VAE (للتلوين)",inputs:{grow_mask_by:{name:"توسيع القناع بمقدار"},mask:{name:"قناع"},pixels:{name:"بكسلات"},vae:{name:"vae"}}},Am={display_name:"ترميز VAE (مبسط)",inputs:{overlap:{name:"التداخل"},pixels:{name:"بكسلات"},temporal_overlap:{name:"التداخل الزمني",tooltip:"يستخدم فقط لـ VAEs الفيديو: عدد الإطارات المتداخلة."},temporal_size:{name:"الحجم الزمني",tooltip:"يستخدم فقط لـ VAEs الفيديو: عدد الإطارات التي يتم ترميزها في مرة واحدة."},tile_size:{name:"حجم القطعة"},vae:{name:"vae"}}},Vm={display_name:"تحميل VAE",inputs:{vae_name:{name:"اسم VAE"}}},xm={display_name:"حفظ VAE",inputs:{filename_prefix:{name:"بادئة اسم الملف"},vae:{name:"vae"}}},Tm={display_name:"مجدول VP",inputs:{beta_d:{name:"بيتا د"},beta_min:{name:"بيتا الأدنى"},eps_s:{name:"إبسيلون س"},steps:{name:"الخطوات"}}},Em={description:"ينشئ فيديوهات من وصف نصي باستخدام واجهة Google Veo API",display_name:"توليد فيديو Google Veo2",inputs:{aspect_ratio:{name:"نسبة العرض إلى الارتفاع",tooltip:"نسبة العرض إلى الارتفاع للفيديو الناتج"},control_after_generate:{name:"التحكم بعد التوليد"},duration_seconds:{name:"مدة الفيديو بالثواني",tooltip:"مدة الفيديو الناتج بالثواني"},enhance_prompt:{name:"تعزيز الوصف",tooltip:"هل يتم تعزيز الوصف بمساعدة الذكاء الاصطناعي"},image:{name:"صورة مرجعية",tooltip:"صورة مرجعية اختيارية لتوجيه توليد الفيديو"},negative_prompt:{name:"الوصف السلبي",tooltip:"الوصف النصي السلبي لتوجيه ما يجب تجنبه في الفيديو"},person_generation:{name:"توليد الأشخاص",tooltip:"هل يُسمح بتوليد أشخاص في الفيديو"},prompt:{name:"الوصف النصي",tooltip:"الوصف النصي للفيديو"},seed:{name:"البذرة",tooltip:"بذرة توليد الفيديو (0 عشوائي)"}}},Dm={display_name:"توجيه VideoLinearCFG",inputs:{min_cfg:{name:"الحد الأدنى للـ CFG"},model:{name:"النموذج"}}},Nm={display_name:"توجيه VideoTriangleCFG",inputs:{min_cfg:{name:"الحد الأدنى للـ CFG"},model:{name:"النموذج"}}},Gm={display_name:"تحويل الفوكسل إلى شبكة",inputs:{algorithm:{name:"الخوارزمية"},threshold:{name:"العَتَبة"},voxel:{name:"فوكسل"}}},Fm={display_name:"تحويل الفوكسل إلى شبكة أساسية",inputs:{threshold:{name:"العَتَبة"},voxel:{name:"فوكسل"}}},Rm={display_name:"وان إطار أول وآخر إلى فيديو",inputs:{batch_size:{name:"حجم الدفعة"},clip_vision_end_image:{name:"صورة نهاية رؤية الكليب"},clip_vision_start_image:{name:"صورة بداية رؤية الكليب"},end_image:{name:"صورة النهاية"},height:{name:"الارتفاع"},length:{name:"الطول"},negative:{name:"سلبي"},positive:{name:"إيجابي"},start_image:{name:"صورة البداية"},vae:{name:"vae"},width:{name:"العرض"}},outputs:{0:{name:"إيجابي"},1:{name:"سلبي"},2:{name:"مضمر"}}},Bm={display_name:"وان تحكم ممتع إلى فيديو",inputs:{batch_size:{name:"حجم الدفعة"},clip_vision_output:{name:"ناتج رؤية الكليب"},control_video:{name:"فيديو التحكم"},height:{name:"الارتفاع"},length:{name:"الطول"},negative:{name:"سلبي"},positive:{name:"إيجابي"},start_image:{name:"صورة البداية"},vae:{name:"vae"},width:{name:"العرض"}},outputs:{0:{name:"إيجابي"},1:{name:"سلبي"},2:{name:"مضمر"}}},wm={display_name:"وان تلوين ممتع إلى فيديو",inputs:{batch_size:{name:"حجم الدفعة"},clip_vision_output:{name:"ناتج رؤية الكليب"},end_image:{name:"صورة النهاية"},height:{name:"الارتفاع"},length:{name:"الطول"},negative:{name:"سلبي"},positive:{name:"إيجابي"},start_image:{name:"صورة البداية"},vae:{name:"vae"},width:{name:"العرض"}},outputs:{0:{name:"إيجابي"},1:{name:"سلبي"},2:{name:"مضمر"}}},Um={display_name:"وان صورة إلى فيديو",inputs:{batch_size:{name:"حجم الدفعة"},clip_vision_output:{name:"ناتج رؤية الكليب"},height:{name:"الارتفاع"},length:{name:"الطول"},negative:{name:"سلبي"},positive:{name:"إيجابي"},start_image:{name:"صورة البداية"},vae:{name:"vae"},width:{name:"العرض"}},outputs:{0:{name:"إيجابي"},1:{name:"سلبي"},2:{name:"مضمر"}}},jm={display_name:"وان Vace إلى فيديو",inputs:{batch_size:{name:"حجم الدفعة"},control_masks:{name:"أقنعة التحكم"},control_video:{name:"فيديو التحكم"},height:{name:"الارتفاع"},length:{name:"الطول"},negative:{name:"سلبي"},positive:{name:"إيجابي"},reference_image:{name:"صورة مرجعية"},strength:{name:"القوة"},vae:{name:"vae"},width:{name:"العرض"}},outputs:{0:{name:"إيجابي"},1:{name:"سلبي"},2:{name:"مضمر"},3:{name:"اقتطاع المضمر"}}},Hm={display_name:"التقاط كاميرا ويب",inputs:{capture_on_queue:{name:"التقاط في الطابور"},height:{name:"الارتفاع"},image:{name:"صورة"},"waiting for camera___":{},width:{name:"العرض"}}},Xm={display_name:"محمل نقطة فحص unCLIP",inputs:{ckpt_name:{name:"اسم نقطة الفحص"}}},zm={display_name:"تكييف unCLIP",inputs:{clip_vision_output:{name:"ناتج رؤية الكليب"},conditioning:{name:"التكييف"},noise_augmentation:{name:"زيادة الضجيج"},strength:{name:"القوة"}}},Km={AddNoise:e,AlignYourStepsScheduler:n,BasicGuider:a,BasicScheduler:t,BetaSamplingScheduler:o,CFGGuider:m,CFGZeroStar:i,CLIPAttentionMultiply:s,CLIPLoader:_,CLIPMergeAdd:l,CLIPMergeSimple:p,CLIPMergeSubtract:c,CLIPSave:d,CLIPSetLastLayer:r,CLIPTextEncode:u,CLIPTextEncodeControlnet:g,CLIPTextEncodeFlux:b,CLIPTextEncodeHiDream:y,CLIPTextEncodeHunyuanDiT:k,CLIPTextEncodeLumina2:h,CLIPTextEncodePixArtAlpha:L,CLIPTextEncodeSD3:C,CLIPTextEncodeSDXL:S,CLIPTextEncodeSDXLRefiner:f,CLIPVisionEncode:v,CLIPVisionLoader:I,Canny:P,CheckpointLoader:M,CheckpointLoaderSimple:A,CheckpointSave:V,CombineHooks2:x,CombineHooks4:T,CombineHooks8:E,ConditioningAverage:D,ConditioningCombine:N,ConditioningConcat:G,ConditioningSetArea:F,ConditioningSetAreaPercentage:R,ConditioningSetAreaPercentageVideo:B,ConditioningSetAreaStrength:w,ConditioningSetDefaultCombine:U,ConditioningSetMask:j,ConditioningSetProperties:H,ConditioningSetPropertiesAndCombine:X,ConditioningSetTimestepRange:z,ConditioningStableAudio:K,ConditioningTimestepsRange:O,ConditioningZeroOut:W,ControlNetApply:Y,ControlNetApplyAdvanced:q,ControlNetApplySD3:Z,ControlNetInpaintingAliMamaApply:Q,ControlNetLoader:J,CosmosImageToVideoLatent:$,CreateHookKeyframe:ee,CreateHookKeyframesFromFloats:ne,CreateHookKeyframesInterpolated:ae,CreateHookLora:te,CreateHookLoraModelOnly:oe,CreateHookModelAsLora:me,CreateHookModelAsLoraModelOnly:ie,CreateVideo:se,CropMask:_e,DiffControlNetLoader:le,DifferentialDiffusion:pe,DiffusersLoader:ce,DisableNoise:de,DualCFGGuider:re,DualCLIPLoader:ue,EmptyCosmosLatentVideo:ge,EmptyHunyuanLatentVideo:be,EmptyImage:ye,EmptyLTXVLatentVideo:ke,EmptyLatentAudio:he,EmptyLatentHunyuan3Dv2:Le,EmptyLatentImage:Ce,EmptyMochiLatentVideo:Se,EmptySD3LatentImage:fe,ExponentialScheduler:ve,ExtendIntermediateSigmas:Ie,FeatherMask:Pe,FlipSigmas:Me,FluxDisableGuidance:Ae,FluxGuidance:Ve,FluxProExpandNode:xe,FluxProFillNode:Te,FluxProUltraImageNode:Ee,FreSca:De,FreeU:Ne,FreeU_V2:Ge,GITSScheduler:Fe,GLIGENLoader:Re,GLIGENTextBoxApply:Be,GetVideoComponents:we,GrowMask:Ue,Hunyuan3Dv2Conditioning:je,Hunyuan3Dv2ConditioningMultiView:He,HunyuanImageToVideo:Xe,HyperTile:ze,HypernetworkLoader:Ke,IdeogramV1:Oe,IdeogramV2:We,IdeogramV3:Ye,ImageBatch:qe,ImageBlend:Ze,ImageBlur:Qe,ImageColorToMask:Je,ImageCompositeMasked:$e,ImageCrop:en,ImageFromBatch:nn,ImageInvert:an,ImageOnlyCheckpointLoader:tn,ImageOnlyCheckpointSave:on,ImagePadForOutpaint:mn,ImageQuantize:sn,ImageRGBToYUV:_n,ImageScale:ln,ImageScaleBy:pn,ImageScaleToTotalPixels:cn,ImageSharpen:dn,ImageToMask:rn,ImageUpscaleWithModel:un,ImageYUVToRGB:gn,InpaintModelConditioning:bn,InstructPixToPixConditioning:yn,InvertMask:kn,JoinImageWithAlpha:hn,KSampler:Ln,KSamplerAdvanced:Cn,KSamplerSelect:Sn,KarrasScheduler:fn,KlingCameraControlI2VNode:vn,KlingCameraControlT2VNode:In,KlingCameraControls:Pn,KlingDualCharacterVideoEffectNode:Mn,KlingImage2VideoNode:An,KlingImageGenerationNode:Vn,KlingLipSyncAudioToVideoNode:xn,KlingLipSyncTextToVideoNode:Tn,KlingSingleImageVideoEffectNode:En,KlingStartEndFrameNode:Dn,KlingTextToVideoNode:Nn,KlingVideoExtendNode:Gn,KlingVirtualTryOnNode:Fn,LTXVAddGuide:Rn,LTXVConditioning:Bn,LTXVCropGuides:wn,LTXVImgToVideo:Un,LTXVPreprocess:jn,LTXVScheduler:Hn,LaplaceScheduler:Xn,LatentAdd:zn,LatentApplyOperation:Kn,LatentApplyOperationCFG:On,LatentBatch:Wn,LatentBatchSeedBehavior:Yn,LatentBlend:qn,LatentComposite:Zn,LatentCompositeMasked:Qn,LatentCrop:Jn,LatentFlip:$n,LatentFromBatch:ea,LatentInterpolate:na,LatentMultiply:aa,LatentOperationSharpen:ta,LatentOperationTonemapReinhard:oa,LatentRotate:ma,LatentSubtract:ia,LatentUpscale:sa,LatentUpscaleBy:_a,Load3D:la,Load3DAnimation:pa,LoadAudio:ca,LoadImage:da,LoadImageMask:ra,LoadImageOutput:ua,LoadLatent:ga,LoadVideo:ba,LoraLoader:ya,LoraLoaderModelOnly:ka,LoraSave:ha,LotusConditioning:La,LumaConceptsNode:Ca,LumaImageModifyNode:Sa,LumaImageNode:fa,LumaImageToVideoNode:va,LumaReferenceNode:Ia,LumaVideoNode:Pa,Mahiro:Ma,MaskComposite:Aa,MaskPreview:Va,MaskToImage:xa,MinimaxImageToVideoNode:Ta,MinimaxTextToVideoNode:Ea,ModelComputeDtype:Da,ModelMergeAdd:Na,ModelMergeAuraflow:Ga,ModelMergeBlocks:Fa,ModelMergeCosmos14B:Ra,ModelMergeCosmos7B:Ba,ModelMergeFlux1:wa,ModelMergeLTXV:Ua,ModelMergeMochiPreview:ja,ModelMergeSD1:Ha,ModelMergeSD2:Xa,ModelMergeSD35_Large:za,ModelMergeSD3_2B:Ka,ModelMergeSDXL:Oa,ModelMergeSimple:Wa,ModelMergeSubtract:Ya,ModelMergeWAN2_1:qa,ModelSamplingAuraFlow:Za,ModelSamplingContinuousEDM:Qa,ModelSamplingContinuousV:Ja,ModelSamplingDiscrete:$a,ModelSamplingFlux:et,ModelSamplingLTXV:nt,ModelSamplingSD3:at,ModelSamplingStableCascade:tt,ModelSave:ot,Morphology:mt,OpenAIDalle2:it,OpenAIDalle3:st,OpenAIGPTImage1:_t,OptimalStepsScheduler:lt,PairConditioningCombine:pt,PairConditioningSetDefaultCombine:ct,PairConditioningSetProperties:dt,PairConditioningSetPropertiesAndCombine:rt,PatchModelAddDownscale:ut,PerpNeg:gt,PerpNegGuider:bt,PerturbedAttentionGuidance:yt,PhotoMakerEncode:kt,PhotoMakerLoader:ht,PikaImageToVideoNode2_2:Lt,PikaScenesV2_2:Ct,PikaStartEndFrameNode2_2:St,PikaTextToVideoNode2_2:ft,Pikadditions:vt,Pikaffects:It,Pikaswaps:Pt,PixverseImageToVideoNode:Mt,PixverseTemplateNode:At,PixverseTextToVideoNode:Vt,PixverseTransitionVideoNode:xt,PolyexponentialScheduler:Tt,PorterDuffImageComposite:Et,Preview3D:Dt,Preview3DAnimation:Nt,PreviewAny:Gt,PreviewAudio:Ft,PreviewImage:Rt,PrimitiveBoolean:Bt,PrimitiveFloat:wt,PrimitiveInt:Ut,PrimitiveString:jt,PrimitiveStringMultiline:Ht,QuadrupleCLIPLoader:Xt,RandomNoise:zt,RebatchImages:Kt,RebatchLatents:Ot,RecraftColorRGB:Wt,RecraftControls:Yt,RecraftCreativeUpscaleNode:qt,RecraftCrispUpscaleNode:Zt,RecraftImageInpaintingNode:Qt,RecraftImageToImageNode:Jt,RecraftRemoveBackgroundNode:$t,RecraftReplaceBackgroundNode:eo,RecraftStyleV3DigitalIllustration:no,RecraftStyleV3InfiniteStyleLibrary:ao,RecraftStyleV3LogoRaster:to,RecraftStyleV3RealisticImage:oo,RecraftTextToImageNode:mo,RecraftTextToVectorNode:io,RecraftVectorizeImageNode:so,RenormCFG:_o,RepeatImageBatch:lo,RepeatLatentBatch:po,RescaleCFG:co,SDTurboScheduler:ro,SD_4XUpscale_Conditioning:uo,SV3D_Conditioning:go,SVD_img2vid_Conditioning:bo,SamplerCustom:yo,SamplerCustomAdvanced:ko,SamplerDPMAdaptative:ho,SamplerDPMPP_2M_SDE:Lo,SamplerDPMPP_2S_Ancestral:Co,SamplerDPMPP_3M_SDE:So,SamplerDPMPP_SDE:fo,SamplerEulerAncestral:vo,SamplerEulerAncestralCFGPP:Io,SamplerEulerCFGpp:Po,SamplerLCMUpscale:Mo,SamplerLMS:Ao,SaveAnimatedPNG:Vo,SaveAnimatedWEBP:xo,SaveAudio:To,SaveGLB:Eo,SaveImage:Do,SaveImageWebsocket:No,SaveLatent:Go,SaveVideo:Fo,SaveWEBM:Ro,SelfAttentionGuidance:Bo,SetClipHooks:wo,SetFirstSigma:Uo,SetHookKeyframes:jo,SetLatentNoiseMask:Ho,SetUnionControlNetType:Xo,SkipLayerGuidanceDiT:zo,SkipLayerGuidanceSD3:Ko,SolidMask:Oo,SplitImageWithAlpha:Wo,SplitSigmas:Yo,SplitSigmasDenoise:qo,StabilityStableImageSD_3_5Node:Zo,StabilityStableImageUltraNode:Qo,StabilityUpscaleConservativeNode:Jo,StabilityUpscaleCreativeNode:$o,StabilityUpscaleFastNode:em,StableCascade_EmptyLatentImage:nm,StableCascade_StageB_Conditioning:am,StableCascade_StageC_VAEEncode:tm,StableCascade_SuperResolutionControlnet:om,StableZero123_Conditioning:mm,StableZero123_Conditioning_Batched:im,StyleModelApply:sm,StyleModelLoader:_m,T5TokenizerOptions:lm,TextEncodeHunyuanVideo_ImageToVideo:pm,ThresholdMask:cm,TomePatchModel:dm,TorchCompileModel:rm,TrimVideoLatent:um,TripleCLIPLoader:gm,UNETLoader:bm,UNetCrossAttentionMultiply:ym,UNetSelfAttentionMultiply:km,UNetTemporalAttentionMultiply:hm,UpscaleModelLoader:Lm,VAEDecode:Cm,VAEDecodeAudio:Sm,VAEDecodeHunyuan3D:fm,VAEDecodeTiled:vm,VAEEncode:Im,VAEEncodeAudio:Pm,VAEEncodeForInpaint:Mm,VAEEncodeTiled:Am,VAELoader:Vm,VAESave:xm,VPScheduler:Tm,VeoVideoGenerationNode:Em,VideoLinearCFGGuidance:Dm,VideoTriangleCFGGuidance:Nm,VoxelToMesh:Gm,VoxelToMeshBasic:Fm,WanFirstLastFrameToVideo:Rm,WanFunControlToVideo:Bm,WanFunInpaintToVideo:wm,WanImageToVideo:Um,WanVaceToVideo:jm,WebcamCapture:Hm,unCLIPCheckpointLoader:Xm,unCLIPConditioning:zm};export{e as AddNoise,n as AlignYourStepsScheduler,a as BasicGuider,t as BasicScheduler,o as BetaSamplingScheduler,m as CFGGuider,i as CFGZeroStar,s as CLIPAttentionMultiply,_ as CLIPLoader,l as CLIPMergeAdd,p as CLIPMergeSimple,c as CLIPMergeSubtract,d as CLIPSave,r as CLIPSetLastLayer,u as CLIPTextEncode,g as CLIPTextEncodeControlnet,b as CLIPTextEncodeFlux,y as CLIPTextEncodeHiDream,k as CLIPTextEncodeHunyuanDiT,h as CLIPTextEncodeLumina2,L as CLIPTextEncodePixArtAlpha,C as CLIPTextEncodeSD3,S as CLIPTextEncodeSDXL,f as CLIPTextEncodeSDXLRefiner,v as CLIPVisionEncode,I as CLIPVisionLoader,P as Canny,M as CheckpointLoader,A as CheckpointLoaderSimple,V as CheckpointSave,x as CombineHooks2,T as CombineHooks4,E as CombineHooks8,D as ConditioningAverage,N as ConditioningCombine,G as ConditioningConcat,F as ConditioningSetArea,R as ConditioningSetAreaPercentage,B as ConditioningSetAreaPercentageVideo,w as ConditioningSetAreaStrength,U as ConditioningSetDefaultCombine,j as ConditioningSetMask,H as ConditioningSetProperties,X as ConditioningSetPropertiesAndCombine,z as ConditioningSetTimestepRange,K as ConditioningStableAudio,O as ConditioningTimestepsRange,W as ConditioningZeroOut,Y as ControlNetApply,q as ControlNetApplyAdvanced,Z as ControlNetApplySD3,Q as ControlNetInpaintingAliMamaApply,J as ControlNetLoader,$ as CosmosImageToVideoLatent,ee as CreateHookKeyframe,ne as CreateHookKeyframesFromFloats,ae as CreateHookKeyframesInterpolated,te as CreateHookLora,oe as CreateHookLoraModelOnly,me as CreateHookModelAsLora,ie as CreateHookModelAsLoraModelOnly,se as CreateVideo,_e as CropMask,le as DiffControlNetLoader,pe as DifferentialDiffusion,ce as DiffusersLoader,de as DisableNoise,re as DualCFGGuider,ue as DualCLIPLoader,ge as EmptyCosmosLatentVideo,be as EmptyHunyuanLatentVideo,ye as EmptyImage,ke as EmptyLTXVLatentVideo,he as EmptyLatentAudio,Le as EmptyLatentHunyuan3Dv2,Ce as EmptyLatentImage,Se as EmptyMochiLatentVideo,fe as EmptySD3LatentImage,ve as ExponentialScheduler,Ie as ExtendIntermediateSigmas,Pe as FeatherMask,Me as FlipSigmas,Ae as FluxDisableGuidance,Ve as FluxGuidance,xe as FluxProExpandNode,Te as FluxProFillNode,Ee as FluxProUltraImageNode,De as FreSca,Ne as FreeU,Ge as FreeU_V2,Fe as GITSScheduler,Re as GLIGENLoader,Be as GLIGENTextBoxApply,we as GetVideoComponents,Ue as GrowMask,je as Hunyuan3Dv2Conditioning,He as Hunyuan3Dv2ConditioningMultiView,Xe as HunyuanImageToVideo,ze as HyperTile,Ke as HypernetworkLoader,Oe as IdeogramV1,We as IdeogramV2,Ye as IdeogramV3,qe as ImageBatch,Ze as ImageBlend,Qe as ImageBlur,Je as ImageColorToMask,$e as ImageCompositeMasked,en as ImageCrop,nn as ImageFromBatch,an as ImageInvert,tn as ImageOnlyCheckpointLoader,on as ImageOnlyCheckpointSave,mn as ImagePadForOutpaint,sn as ImageQuantize,_n as ImageRGBToYUV,ln as ImageScale,pn as ImageScaleBy,cn as ImageScaleToTotalPixels,dn as ImageSharpen,rn as ImageToMask,un as ImageUpscaleWithModel,gn as ImageYUVToRGB,bn as InpaintModelConditioning,yn as InstructPixToPixConditioning,kn as InvertMask,hn as JoinImageWithAlpha,Ln as KSampler,Cn as KSamplerAdvanced,Sn as KSamplerSelect,fn as KarrasScheduler,vn as KlingCameraControlI2VNode,In as KlingCameraControlT2VNode,Pn as KlingCameraControls,Mn as KlingDualCharacterVideoEffectNode,An as KlingImage2VideoNode,Vn as KlingImageGenerationNode,xn as KlingLipSyncAudioToVideoNode,Tn as KlingLipSyncTextToVideoNode,En as KlingSingleImageVideoEffectNode,Dn as KlingStartEndFrameNode,Nn as KlingTextToVideoNode,Gn as KlingVideoExtendNode,Fn as KlingVirtualTryOnNode,Rn as LTXVAddGuide,Bn as LTXVConditioning,wn as LTXVCropGuides,Un as LTXVImgToVideo,jn as LTXVPreprocess,Hn as LTXVScheduler,Xn as LaplaceScheduler,zn as LatentAdd,Kn as LatentApplyOperation,On as LatentApplyOperationCFG,Wn as LatentBatch,Yn as LatentBatchSeedBehavior,qn as LatentBlend,Zn as LatentComposite,Qn as LatentCompositeMasked,Jn as LatentCrop,$n as LatentFlip,ea as LatentFromBatch,na as LatentInterpolate,aa as LatentMultiply,ta as LatentOperationSharpen,oa as LatentOperationTonemapReinhard,ma as LatentRotate,ia as LatentSubtract,sa as LatentUpscale,_a as LatentUpscaleBy,la as Load3D,pa as Load3DAnimation,ca as LoadAudio,da as LoadImage,ra as LoadImageMask,ua as LoadImageOutput,ga as LoadLatent,ba as LoadVideo,ya as LoraLoader,ka as LoraLoaderModelOnly,ha as LoraSave,La as LotusConditioning,Ca as LumaConceptsNode,Sa as LumaImageModifyNode,fa as LumaImageNode,va as LumaImageToVideoNode,Ia as LumaReferenceNode,Pa as LumaVideoNode,Ma as Mahiro,Aa as MaskComposite,Va as MaskPreview,xa as MaskToImage,Ta as MinimaxImageToVideoNode,Ea as MinimaxTextToVideoNode,Da as ModelComputeDtype,Na as ModelMergeAdd,Ga as ModelMergeAuraflow,Fa as ModelMergeBlocks,Ra as ModelMergeCosmos14B,Ba as ModelMergeCosmos7B,wa as ModelMergeFlux1,Ua as ModelMergeLTXV,ja as ModelMergeMochiPreview,Ha as ModelMergeSD1,Xa as ModelMergeSD2,za as ModelMergeSD35_Large,Ka as ModelMergeSD3_2B,Oa as ModelMergeSDXL,Wa as ModelMergeSimple,Ya as ModelMergeSubtract,qa as ModelMergeWAN2_1,Za as ModelSamplingAuraFlow,Qa as ModelSamplingContinuousEDM,Ja as ModelSamplingContinuousV,$a as ModelSamplingDiscrete,et as ModelSamplingFlux,nt as ModelSamplingLTXV,at as ModelSamplingSD3,tt as ModelSamplingStableCascade,ot as ModelSave,mt as Morphology,it as OpenAIDalle2,st as OpenAIDalle3,_t as OpenAIGPTImage1,lt as OptimalStepsScheduler,pt as PairConditioningCombine,ct as PairConditioningSetDefaultCombine,dt as PairConditioningSetProperties,rt as PairConditioningSetPropertiesAndCombine,ut as PatchModelAddDownscale,gt as PerpNeg,bt as PerpNegGuider,yt as PerturbedAttentionGuidance,kt as PhotoMakerEncode,ht as PhotoMakerLoader,Lt as PikaImageToVideoNode2_2,Ct as PikaScenesV2_2,St as PikaStartEndFrameNode2_2,ft as PikaTextToVideoNode2_2,vt as Pikadditions,It as Pikaffects,Pt as Pikaswaps,Mt as PixverseImageToVideoNode,At as PixverseTemplateNode,Vt as PixverseTextToVideoNode,xt as PixverseTransitionVideoNode,Tt as PolyexponentialScheduler,Et as PorterDuffImageComposite,Dt as Preview3D,Nt as Preview3DAnimation,Gt as PreviewAny,Ft as PreviewAudio,Rt as PreviewImage,Bt as PrimitiveBoolean,wt as PrimitiveFloat,Ut as PrimitiveInt,jt as PrimitiveString,Ht as PrimitiveStringMultiline,Xt as QuadrupleCLIPLoader,zt as RandomNoise,Kt as RebatchImages,Ot as RebatchLatents,Wt as RecraftColorRGB,Yt as RecraftControls,qt as RecraftCreativeUpscaleNode,Zt as RecraftCrispUpscaleNode,Qt as RecraftImageInpaintingNode,Jt as RecraftImageToImageNode,$t as RecraftRemoveBackgroundNode,eo as RecraftReplaceBackgroundNode,no as RecraftStyleV3DigitalIllustration,ao as RecraftStyleV3InfiniteStyleLibrary,to as RecraftStyleV3LogoRaster,oo as RecraftStyleV3RealisticImage,mo as RecraftTextToImageNode,io as RecraftTextToVectorNode,so as RecraftVectorizeImageNode,_o as RenormCFG,lo as RepeatImageBatch,po as RepeatLatentBatch,co as RescaleCFG,ro as SDTurboScheduler,uo as SD_4XUpscale_Conditioning,go as SV3D_Conditioning,bo as SVD_img2vid_Conditioning,yo as SamplerCustom,ko as SamplerCustomAdvanced,ho as SamplerDPMAdaptative,Lo as SamplerDPMPP_2M_SDE,Co as SamplerDPMPP_2S_Ancestral,So as SamplerDPMPP_3M_SDE,fo as SamplerDPMPP_SDE,vo as SamplerEulerAncestral,Io as SamplerEulerAncestralCFGPP,Po as SamplerEulerCFGpp,Mo as SamplerLCMUpscale,Ao as SamplerLMS,Vo as SaveAnimatedPNG,xo as SaveAnimatedWEBP,To as SaveAudio,Eo as SaveGLB,Do as SaveImage,No as SaveImageWebsocket,Go as SaveLatent,Fo as SaveVideo,Ro as SaveWEBM,Bo as SelfAttentionGuidance,wo as SetClipHooks,Uo as SetFirstSigma,jo as SetHookKeyframes,Ho as SetLatentNoiseMask,Xo as SetUnionControlNetType,zo as SkipLayerGuidanceDiT,Ko as SkipLayerGuidanceSD3,Oo as SolidMask,Wo as SplitImageWithAlpha,Yo as SplitSigmas,qo as SplitSigmasDenoise,Zo as StabilityStableImageSD_3_5Node,Qo as StabilityStableImageUltraNode,Jo as StabilityUpscaleConservativeNode,$o as StabilityUpscaleCreativeNode,em as StabilityUpscaleFastNode,nm as StableCascade_EmptyLatentImage,am as StableCascade_StageB_Conditioning,tm as StableCascade_StageC_VAEEncode,om as StableCascade_SuperResolutionControlnet,mm as StableZero123_Conditioning,im as StableZero123_Conditioning_Batched,sm as StyleModelApply,_m as StyleModelLoader,lm as T5TokenizerOptions,pm as TextEncodeHunyuanVideo_ImageToVideo,cm as ThresholdMask,dm as TomePatchModel,rm as TorchCompileModel,um as TrimVideoLatent,gm as TripleCLIPLoader,bm as UNETLoader,ym as UNetCrossAttentionMultiply,km as UNetSelfAttentionMultiply,hm as UNetTemporalAttentionMultiply,Lm as UpscaleModelLoader,Cm as VAEDecode,Sm as VAEDecodeAudio,fm as VAEDecodeHunyuan3D,vm as VAEDecodeTiled,Im as VAEEncode,Pm as VAEEncodeAudio,Mm as VAEEncodeForInpaint,Am as VAEEncodeTiled,Vm as VAELoader,xm as VAESave,Tm as VPScheduler,Em as VeoVideoGenerationNode,Dm as VideoLinearCFGGuidance,Nm as VideoTriangleCFGGuidance,Gm as VoxelToMesh,Fm as VoxelToMeshBasic,Rm as WanFirstLastFrameToVideo,Bm as WanFunControlToVideo,wm as WanFunInpaintToVideo,Um as WanImageToVideo,jm as WanVaceToVideo,Hm as WebcamCapture,Km as default,Xm as unCLIPCheckpointLoader,zm as unCLIPConditioning};
//# sourceMappingURL=nodeDefs-C6QqNODZ.js.map
